@@ -36,15 +36,36 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkConfigure.h>
 
 
-#if (VTK_MAJOR_VERSION == 4)
-#define IVTK_4
+#if (VTK_MAJOR_VERSION<4 || (VTK_MAJOR_VERSION==4 && VTK_MINOR_VERSION<4))
+#error "This version of VTK is too old and is no longer supported."
 #endif
 
-#if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION==0 && VTK_BUILD_VERSION<2)
+
+
+#if (VTK_MAJOR_VERSION==4 && VTK_MINOR_VERSION==4)
+#define IVTK_44
+#endif
+
+#if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION==0)
+#define IVTK_50
+#if (VTK_BUILD_VERSION < 2)
 #define IVTK_501
 #endif
+#endif
 
-#ifdef IVTK_4
+#if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION==2)
+#define IVTK_52
+#endif
+
+#if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION==4)
+#define IVTK_54
+#if (VTK_BUILD_VERSION < 1)
+#define IVTK_540
+#endif
+#endif
+
+
+#ifdef IVTK_44
 
 class vtkSource;
 typedef vtkSource ivtkFilter;
@@ -72,4 +93,22 @@ typedef vtkPolyDataAlgorithm ivtkPolyDataFilter;
 
 #endif
 
+
+#if defined(IVTK_44) || defined(IVTK_50)
+#define IVTK_PRE52
+#endif
+
+
+#if defined(IVTK_PRE52) || defined(IVTK_52)
+#define IVTK_PRE54
+#endif
+
+#if defined(IVTK_540)
+//
+//  A bug workaround - hopefully, temporary!!!
+//
+#include <vtkOpenGLPolyDataMapper.h>
+#define vtkPolyDataMapper vtkOpenGLPolyDataMapper
+#endif
+
 #endif // IVTK_H
