@@ -104,7 +104,7 @@ bool _class_##_method_(iScript *self, const iString& value) \
 
 
 #define DEFINE_WORKER_LIMIT(_name_,_limit_) \
-bool _class_##_method_(iScript *self, short at, int num, float *value, int index = -1) \
+bool _class_##_method_(iScript *self, short at, int num, float *value, int index) \
 { \
 	iDataLimits *lim = curLimits(_name_##DataSubject::DataType()); \
 	if(lim!=0 && index>=0 && index<lim->GetNumVars()) \
@@ -130,7 +130,7 @@ bool _class_##Show(iScript *self, short, bool value) \
 
 
 #define DEFINE_WORKER_SUBJECT_BEGIN(_class_,_method_,_type_,_rel_) \
-bool _class_##_method_(iScript *self, short at, int num, const _type_ *value, int index = -1) \
+bool _class_##_method_(iScript *self, short at, int num, const _type_ *value, int index) \
 { \
 	VECTOR_HELPER_ASSERT((curObjectFamily(_class_)->GetMaxMemberIndex()+1)); \
 	i##_class_##ViewSubject *sub; \
