@@ -37,11 +37,15 @@ public:
 
 	iColor();
 	iColor(const iColor &c);
-	iColor(int r, int g, int b);
+	iColor(int r, int g, int b, int a = 255);
+	iColor(double c[3], double alpha = 1.0);
 
 	inline int Red() const { return mRed; }
 	inline int Green() const { return mGreen; }
 	inline int Blue() const { return mBlue; }
+	inline int Alpha() const { return mAlpha; }
+
+	inline int Intensity() const { return (mRed+mGreen+mBlue)/3; }
 
 	inline void GetRGB(char rgb[3]) const { rgb[0] = (char)mRed; rgb[1] = (char)mGreen; rgb[2] = (char)mBlue; }
 	inline void GetRGB(unsigned char rgb[3]) const { rgb[0] = (unsigned char)mRed; rgb[1] = (unsigned char)mGreen; rgb[2] = (unsigned char)mBlue; }
@@ -54,11 +58,20 @@ public:
     friend bool operator==(const iColor &s1, const iColor &s2);
     friend bool operator!=(const iColor &s1, const iColor &s2);
 
+	bool IsValid() const;
+
+	//
+	//  Some colors
+	//
+	static const iColor& Black();
+	static const iColor& White();
+	static const iColor& Invalid();
+
 private:
 
 	void Update();
 
-	int mRed, mGreen, mBlue;
+	int mRed, mGreen, mBlue, mAlpha;
 	double mVTK[4];
 };
 
@@ -68,11 +81,12 @@ inline void iColor::Update()
 	mVTK[0] = mRed/255.0;
 	mVTK[1] = mGreen/255.0;
 	mVTK[2] = mBlue/255.0;
-	mVTK[3] = 1.0;
+	mVTK[3] = mAlpha/255.0;
 }
 
 inline iColor::iColor()
 {
+	mAlpha = 1;
 	mRed = mGreen = mBlue = 0;
 	this->Update();
 }
@@ -83,41 +97,46 @@ inline iColor::iColor(const iColor &c)
 	mRed = c.mRed;
 	mGreen = c.mGreen;
 	mBlue = c.mBlue;
+	mAlpha = c.mAlpha;
 	this->Update();
 }
 
 
-inline iColor::iColor(int r, int g, int b)
+inline iColor::iColor(int r, int g, int b, int a)
 {
 	mRed = r;
 	mGreen = g;
 	mBlue = b;
+	mAlpha = a;
 	this->Update();
 }
 
 
-inline iColor iColor::Reverse() const
+inline iColor::iColor(double c[3], double alpha)
 {
-	return iColor(255-mRed,255-mGreen,255-mBlue);
-}
-
-
-inline iColor iColor::Shadow() const
-{
-    int c = (mRed+mGreen+mBlue)/3 > 127 ? 0 : 255;
-	return iColor(c,c,c);
+	mRed = int(255*c[0]);
+	mGreen = int(255*c[1]);
+	mBlue = int(255*c[2]);
+	mAlpha = int(255*alpha);
+	this->Update();
 }
 
 
 inline bool operator==(const iColor &s1, const iColor &s2)
 {
-	return (s1.mRed==s2.mRed) && (s1.mGreen==s2.mGreen) && (s1.mBlue==s2.mBlue);
+	return (s1.mRed==s2.mRed) && (s1.mGreen==s2.mGreen) && (s1.mBlue==s2.mBlue) && (s1.mAlpha==s2.mAlpha);
 }
 
 
 inline bool operator!=(const iColor &s1, const iColor &s2)
 {
-	return (s1.mRed!=s2.mRed) || (s1.mGreen!=s2.mGreen) || (s1.mBlue!=s2.mBlue);
+	return (s1.mRed!=s2.mRed) || (s1.mGreen!=s2.mGreen) || (s1.mBlue!=s2.mBlue) || (s1.mAlpha!=s2.mAlpha);
+}
+
+
+inline bool iColor::IsValid() const
+{
+	return (mRed>=0 && mRed<256 && mGreen>=0 && mGreen<256 && mBlue>=0 && mBlue<256 && mAlpha>=0 && mAlpha<256);
 }
 
 #endif // ICOLOR_H
