@@ -35,11 +35,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "idatareader.h"
 #include "idatastretch.h"
 #include "ierror.h"
+#include "igenericprop.h"
 #include "imath.h"
 #include "ioverlayhelper.h"
 #include "ipalette.h"
 #include "itextactor.h"
 #include "iviewmodule.h"
+#include "ivtk.h"
 
 #include <vtkCamera.h>
 #include <vtkLookupTable.h>
@@ -54,6 +56,7 @@ using namespace iParameter;
 //  Templates
 //
 #include "iarraytemplate.h"
+#include "igenericproptemplate.h"
 
 
 IOBJECT_DEFINE_TYPE(iColorBars,ColorBars,cb,iObjectType::_Helper);
@@ -80,10 +83,8 @@ private:
 	{
 		Base = iTextActor::New(parent); IERROR_ASSERT(Base);
 		Power = iTextActor::New(parent); IERROR_ASSERT(Power);
-		Base->SetBold(true);
-		Power->SetBold(true);
-		Base->SetHJustification(left?_TextJustRight:_TextJustLeft);
-		Power->SetHJustification(_TextJustLeft);
+		Base->SetJustification(left?1:-1);
+		Power->SetJustification(-1);
 	}
 
 	~iColorBarLabel()
@@ -96,7 +97,7 @@ private:
 };
 
 
-class iColorBarActor: public vtkActor2D
+class iColorBarActor : public iGenericProp<vtkActor2D>
 {
 	
 	IPOINTER_AS_USER(OverlayHelper);
@@ -106,25 +107,18 @@ public:
 	vtkTypeMacro(iColorBarActor,vtkActor2D);
 	static iColorBarActor* New(bool left = false, iColorBars *parent = 0);
 
-	virtual int RenderOverlay(vtkViewport *vp);
-	virtual int RenderOpaqueGeometry(vtkViewport *vp);
-	virtual int RenderTranslucentGeometry(vtkViewport * ){ return 0; }
-	
-	virtual void ReleaseGraphicsResources(vtkWindow *win);
-
 	void SetSideOffset(float v);
 	inline float GetSideOffset() const { return mOffset; }
 
 	void SetHeight(float v);
 	inline float GetHeight() const { return mHeight*0.86; } // there is a 0.86 factor in vtkScalarBarActor
 
-	void SetFontType(int t);
-	inline int GetFontType() const { return mFontType; }
-
 protected:
 
 	virtual ~iColorBarActor();
 
+	virtual void UpdateGeometry(vtkViewport *vp);
+
 private:
 	
 	iColorBarActor(bool left, iColorBars *parent);
@@ -138,7 +132,7 @@ private:
 	float mHeight, mOffset, mWidth4Height;
 	float mXOff, mYOff;
 	float mLabelOff, mTitleOff;
-	int mJmax, mFontType;
+	int mJmax;
 
 	bool mIsLeft;
 	iColorBars *mParent;
@@ -155,7 +149,7 @@ iColorBarActor* iColorBarActor::New(bool left, iColorBars *parent)
 }
 
 
-iColorBarActor::iColorBarActor(bool left, iColorBars *parent) : mOverlayHelper(parent->GetViewModule()->GetRenderTool())
+iColorBarActor::iColorBarActor(bool left, iColorBars *parent) : iGenericProp<vtkActor2D>(false), mOverlayHelper(parent->GetViewModule()->GetRenderTool())
 {
 	int i;
 
@@ -163,7 +157,6 @@ iColorBarActor::iColorBarActor(bool left, iColorBars *parent) : mOverlayHelper(p
 	mParent = parent;
 	mItem = 0;
 
-	mFontType = _TextTypeBitmapArial;
 	mStarted = false;
 
 	mJmax = 0;
@@ -172,6 +165,7 @@ iColorBarActor::iColorBarActor(bool left, iColorBars *parent) : mOverlayHelper(p
 	mOffset = 0.08;
 
 	mBarActor = vtkScalarBarActor::New(); IERROR_ASSERT(mBarActor);
+	this->AppendComponent(mBarActor);
 	mBarActor->GetPositionCoordinate()->SetCoordinateSystemToNormalizedViewport();
 	mBarActor->SetOrientationToVertical();
 	mBarActor->SetMaximumNumberOfColors(256);
@@ -182,22 +176,22 @@ iColorBarActor::iColorBarActor(bool left, iColorBars *parent) : mOverlayHelper(p
 	mBarActor->PickableOff();
 
 	mTitleActor = iTextActor::New(this->GetOverlayHelper()->GetRenderTool()); IERROR_ASSERT(mTitleActor);
-	mTitleActor->Rotate(90.0);
-	mTitleActor->SetVJustification(_TextJustCenter);
+	this->AppendComponent(mTitleActor);
+	mTitleActor->SetAngle(90.0);
+	mTitleActor->SetJustification(left?-1:1,0);
 	mTitleActor->SetBold(true);
-	mTitleActor->SetFontScale(1);
 
-	mTitleActor->SetHJustification(left?_TextJustLeft:_TextJustRight);
 
 	iColorBarLabel *l;
 	for(i=0; i<10; i++)
 	{
 		l = new iColorBarLabel(left,this->GetOverlayHelper()->GetRenderTool()); IERROR_ASSERT(l);
+		this->AppendComponent(l->Base);
+		this->AppendComponent(l->Power);
 		mLabels.Add(l);
 	}
 
 	this->UpdatePlacement();
-	this->SetFontType(mFontType);
 }
 
 
@@ -252,59 +246,21 @@ void iColorBarActor::SetHeight(float v)
 }
 
 
-void iColorBarActor::SetFontType(int s)
-{
-	int j;
-	mTitleActor->SetFontType(_TextTypeVector);
-	for(j=0; j<mLabels.Size(); j++)
-	{
-		mLabels[j]->Base->SetFontType(s);
-		mLabels[j]->Power->SetFontType(s);
-	}
-	mFontType = mLabels[0]->Base->GetFontType();
-}
-
-	
-void iColorBarActor::ReleaseGraphicsResources(vtkWindow *win)
-{
-	int j;
-	mBarActor->ReleaseGraphicsResources(win);
-	mTitleActor->ReleaseGraphicsResources(win);
-	for(j=0; j<mLabels.Size(); j++)
-	{
-		mLabels[j]->Base->ReleaseGraphicsResources(win);
-		mLabels[j]->Power->ReleaseGraphicsResources(win);
-	}
-	this->vtkProp::ReleaseGraphicsResources(win);
-}
-
-
-int iColorBarActor::RenderOverlay(vtkViewport* viewport)
-{
-	if(!mStarted) return 0;
-	if(mItem==0 || mItem->Count==0 || mItem->Palette==0) return 0;
-
-	mBarActor->RenderOverlay(viewport);
-	mTitleActor->RenderOverlay(viewport);
-
-	int j;
-	for(j=0; j<mLabels.Size(); j++)
-	{
-		mLabels[j]->Base->RenderOverlay(viewport);
-		mLabels[j]->Power->RenderOverlay(viewport);
-	}
-
-	return 1;
-}
-
-
-int iColorBarActor::RenderOpaqueGeometry(vtkViewport* viewport)
+void iColorBarActor::UpdateGeometry(vtkViewport* viewport)
 {
 	mItem = mParent->GetItem(mIsLeft);
-	if(mItem==0 || mItem->Count==0 || mItem->Palette==0) return 0;
+	if(mItem==0 || mItem->Count==0 || mItem->Palette==0)
+	{
+		this->Disable();
+		return;
+	}
 
 	iDataLimits *lim = mParent->GetViewModule()->GetReader()->GetLimits(iDataType::FindTypeById(mItem->DataTypeId));
-	if(lim==0 || mItem->Var>=lim->GetNumVars()) return 0;
+	if(lim==0 || mItem->Var>=lim->GetNumVars())
+	{
+		this->Disable();
+		return;
+	}
 
 	int j;
 	float w1 = 0.0, h1 = 0.0, w2 = 0.0, h2 = 0.0;
@@ -335,7 +291,11 @@ int iColorBarActor::RenderOpaqueGeometry(vtkViewport* viewport)
 				int ivu = 0 + (int)floor(vu+0.01);
 				dv = vu - vl;
 
-				if(dv<=0.0 || ivl>vu) return 0;
+				if(dv<=0.0 || ivl>vu)
+				{
+					this->Disable();
+					return;
+				}
 
 				voff = ivl - vl;
 				int ndex = ivu - ivl;
@@ -482,19 +442,6 @@ int iColorBarActor::RenderOpaqueGeometry(vtkViewport* viewport)
 
 		mBarActor->SetPosition(mag*mXOff-winij[0],mag*mYOff-winij[1]);
 	}
-
-	//
-	//  Render everything
-	//
-	mBarActor->RenderOpaqueGeometry(viewport);
-	mTitleActor->RenderOpaqueGeometry(viewport);
-	for(j=0; j<mLabels.Size(); j++)
-	{
-		mLabels[j]->Base->RenderOpaqueGeometry(viewport);
-		mLabels[j]->Power->RenderOpaqueGeometry(viewport);
-	}	
-
-	return 1;
 }
 
 
@@ -582,14 +529,6 @@ void iColorBars::SetColor(iColor c)
 }
 
 	
-void iColorBars::SetFontType(int s)
-{
-	int i;
-	for(i=0; i<2; i++) mActors[i]->SetFontType(s);
-	this->ClearCache();
-}
-
-	
 void iColorBars::ShowBar(int priority, int v, const iDataType &dt, int p, bool show)
 {
 	int i;
