@@ -89,9 +89,6 @@ public:
 	static const iObjectKey& KeyBarLeft();
 	static const iObjectKey& KeyBarRight();
 
-	void SetFontType(int t);
-	int GetFontType() const;
-
 	void ShowBar(int priority, int v, const iDataType &dt, int p, bool s);
 
 	const iColorBarItem* GetItem(bool left);
