@@ -34,7 +34,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iparallelmanager.h"
 #include "ireplicatedpolydata.h"
 #include "iviewsubject.h"
-#include "iviewsubjectreplicator.h"
 
 #include <vtkCellArray.h>
 #include <vtkFloatArray.h>
@@ -402,10 +401,10 @@ bool iPolyDataCollector::CollectDataBody(iArray<vtkDataSet*> &localOutputs, vtkD
 	const iArray<double> &innerEdges(mDistributor->GetEdges());
 	int extDown = 0;
 	int next = 1;
-	if(mManager->GetViewSubject()->GetReplicator() != 0)
+	if(mManager->GetViewSubject()!=0 && mManager->GetViewSubject()->GetDataReplicated()!=0)
 	{
-		extDown = mManager->GetViewSubject()->GetReplicator()->GetDataReplicated()->GetNumReplicas(2*splitDim);
-		next += mManager->GetViewSubject()->GetReplicator()->GetDataReplicated()->GetNumReplicas(2*splitDim+1) + extDown;
+		extDown = mManager->GetViewSubject()->GetDataReplicated()->GetNumReplicas(2*splitDim);
+		next += mManager->GetViewSubject()->GetDataReplicated()->GetNumReplicas(2*splitDim+1) + extDown;
 	}
 
 	int i, j, numEdges = innerEdges.Size();
