@@ -65,6 +65,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <vtkCamera.h>
 #include <vtkDataObject.h>
+#include <vtkInteractorStyle.h>
 #include <vtkMapper.h>
 #include <vtkRenderer.h>
 #include <vtkRenderWindow.h>
@@ -258,7 +259,7 @@ protected:
 		mInUpdate = mActive = false;
 	}
 
-	virtual void ExecuteBody(vtkObject *caller, unsigned long event, void *callData)
+	virtual void ExecuteBody(vtkObject *caller, unsigned long event1, void *callData)
 	{
 		if(!mActive || mInUpdate) return;
 
@@ -273,7 +274,7 @@ protected:
 				iren->SetShiftKey(driver->GetShiftKey());
 				iren->SetEventPosition(driver->GetEventPosition());
 				iren->SetKeySym(driver->GetKeySym());
-				iren->InvokeEvent(event,callData);
+				iren->InvokeEvent(event1,callData);
 			}
 			mInUpdate = false;
 		}
@@ -643,7 +644,7 @@ void iControlModule::ExecuteForViewModule(iViewModule *module, const iString &co
 	{
 		iMarkerFamily *fam = module->GetMarkerFamily();
 		ExecuteForObject(fam,command,objOption,mExecuteOk);
-		if(mExecuteOk) module->BuildMarkerLegend(module->GetMarkerFamily()->GetCurrentMemberIndex());
+		if(mExecuteOk) module->GetMarkerFamily()->UpdateLegend();
 		if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
 		return;
 	}
@@ -715,8 +716,6 @@ bool iControlModule::CreateObject(const iObjectType &type, bool render, int mod,
 		{
 			if(!iControlModule_Private::CreateObject(fam,module)) return false;
 		}
-		fam->GetCurrentMember()->SetPosition(_LocationFocalPoint);
-		module->BuildMarkerLegend();
 		if(render) module->Render();
 		return true;
 	}
@@ -802,7 +801,6 @@ bool iControlModule::DeleteObject(const iObjectType &type, bool render, int mod,
 		{
 			iControlModule_Private::DeleteObject(fam,module,obj);
 		}
-		module->BuildMarkerLegend();
 		if(render) module->Render();
 		return true;
 	}
