@@ -572,6 +572,14 @@ const iString iDataReader::GetFileSetName(int rec) const
 }
 
 
+const iString iDataReader::GetFileSetRoot() const
+{
+	static const iString none;
+	
+	if(mSetLoaders.Size() > 0) return mSetLoaders[0]->GetFileRoot(); else return none;
+}
+
+
 bool iDataReader::IsCurrentSetMember(const iString &fname) const
 {
 	int i;
