@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
+#include "ivtk.h"
 
 #include <vtkCriticalSection.h>
 
@@ -42,6 +43,10 @@ bool iEventObserver::mAllAreBlocked = false;
 iEventObserver::iEventObserver(iShell *s) : mShell(s)
 {
 	mIsBlocked = mLockedExecute = false;
+
+#ifndef IVTK_PRE52
+	this->PassiveObserverOn(); // O-ho-ho, VTK guys - how I wish you messed less with the basic interface...
+#endif
 	//
 	//  Use this mutex to support multi-threaded execution
 	//
