@@ -30,21 +30,19 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IFAMILY_H
 
 
-#include "ideletable.h"
-
-
 #include "iarray.h"
 
 
 class iView;
 
 template<class Object, class Parent>
-class iFamily : public iDeletable
+class iFamily
 {
 
 public:
 
 	static iFamily<Object,Parent>* New(Parent *p);
+	virtual void Delete(){ delete this; }
 
 	inline int GetMaxMemberIndex() const { return this->mMemlist.MaxIndex(); }
 	inline int GetCurrentMemberIndex() const { return this->mCur; }
@@ -56,7 +54,7 @@ public:
 
 protected:
 
-	iFamily();
+//	iFamily();
 	iFamily(Parent *p);
 	virtual ~iFamily();
 
