@@ -204,7 +204,7 @@ bool iFile::IsReadable(const iString &name)
 bool iFile::IsWritable(const iString &name)
 {
 	iFile F(name);
-	if(!F.Open(_Append,_Text)) return false;
+	if(!F.Open(_ReadWrite,_Text)) return false;
 	F.Close();
 	return true;
 }
