@@ -605,19 +605,26 @@ void iFileLoader::Reset()
 void iFileLoader::ShiftData(double dr[3])
 {
 	int i;
-	double dx[3];
+	double dxmax, dx[3];
 
 	mObserver->Started(iProgressEventObserver::_Shifting);
 	mObserver->SetProgress(0.0);
 
-	for(i=0; i<3; i++) dx[i] = dr[i] - mShift[i];
-
-	for(i=0; i<this->NumStreams(); i++) if(mStreams[i]->ReleasedData != 0)
+	dxmax = 0.0;
+	for(i=0; i<3; i++)
 	{
-		this->ShiftDataBody(mStreams[i]->ReleasedData,dx);
+		dx[i] = dr[i] - mShift[i];
+		if(fabs(dx[i]) > dxmax) dxmax = fabs(dx[i]);
 	}
 
-	for(i=0; i<3; i++) mShift[i] = dr[i];
+	if(dxmax > 1.0e-30)
+	{
+		for(i=0; i<this->NumStreams(); i++) if(mStreams[i]->ReleasedData != 0)
+		{
+			this->ShiftDataBody(mStreams[i]->ReleasedData,dx);
+		}
+		for(i=0; i<3; i++) mShift[i] = dr[i];
+	}
 
 	mObserver->Finished();
 }
