@@ -96,10 +96,11 @@ protected:
 	virtual vtkIdType GetNumberOfCells();
 	virtual void FindPositionForCell(long cell, iPosition &pos);
 	virtual bool PrepareForPass();
+	virtual bool IsValidIndex(vtkIdType l) const;
 	virtual float GetScalarValue(vtkIdType l) const;
 	virtual float GetVectorValue(vtkIdType l) const;
 	virtual float GetTensorValue(vtkIdType l) const;
-	virtual bool IsValidIndex(vtkIdType l) const;
+	virtual double GetValueWeight(vtkIdType l) const;
 
 protected: 
 	
@@ -129,7 +130,7 @@ private:
 		vtkIdType CellMax;
 		vtkIdType CellMin;
 	} *mRanges;
-	float **mValues;
+	double **mValues;
 	//
 	//  Work variables
 	//
