@@ -34,7 +34,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkMath.h>
 #include <vtkRenderer.h>
 
-#ifdef IVTK_4
+#ifdef IVTK_44
 #define HeadLight Headlight
 #endif
 
@@ -46,9 +46,13 @@ namespace iLightKit_Private
 		int i;
 		double org[3], pos[3];
 
+#ifdef IVTK_PRE54
 		elevation *= vtkMath::DegreesToRadians();
 		azimuth *= vtkMath::DegreesToRadians();
-
+#else
+		elevation = vtkMath::RadiansFromDegrees(elevation);
+		azimuth = vtkMath::RadiansFromDegrees(azimuth);
+#endif
 		org[0] = cos(elevation)*sin(azimuth);
 		org[1] = sin(elevation); 
 		org[2] = cos(elevation)*cos(azimuth);
@@ -146,11 +150,17 @@ void iLightKit::UpdateAngles()
 {
 	double ex[3], ey[3], ez[3];
 
+#ifdef IVTK_PRE54
 	double ce = cos(mAngles[0]*vtkMath::DegreesToRadians());
 	double se = sin(mAngles[0]*vtkMath::DegreesToRadians());
-
 	double ca = cos(mAngles[1]*vtkMath::DegreesToRadians());
 	double sa = sin(mAngles[1]*vtkMath::DegreesToRadians());
+#else
+	double ce = cos(vtkMath::RadiansFromDegrees(mAngles[0]));
+	double se = sin(vtkMath::RadiansFromDegrees(mAngles[0]));
+	double ca = cos(vtkMath::RadiansFromDegrees(mAngles[1]));
+	double sa = sin(vtkMath::RadiansFromDegrees(mAngles[1]));
+#endif
 
 	ex[0] =  ce*ca; ex[1] = 0.0; ex[2] = -ce*sa;
 	ey[0] = -se*sa; ey[1] =  ce; ey[2] = -se*ca;
