@@ -208,16 +208,22 @@ void iMarker::FinishMoving()
 
 void iMarker::SetCaptionPosition(const float *x)
 {
-	int j;
-	for(j=0; j<2; j++) mCapPos[j] = x[j];
-	mCaption->SetPosition(x[0],x[1]);
+	this->SetCaptionPosition(x[0],x[1]);
+}
+
+
+void iMarker::SetCaptionPosition(float x, float y)
+{
+	mCapPos[0] = x;
+	mCapPos[1] = y;
+	mCaption->SetPosition(x,y);
 	this->ClearCache();
 }
 
 
 void iMarker::SetSize(double s)
 {
-	if(s>0.0 && s<1.01)
+	if(s > 0.0)
 	{
 		iDistance tmp(this->GetViewModule(),true);
 		tmp = s;
@@ -228,7 +234,7 @@ void iMarker::SetSize(double s)
 
 void iMarker::SetSize(const iDistance &s)
 {
-	if(s < 1.01)
+	if(s < 10.01)
 	{
 		mSize = s;
 		mActors[0]->SetBasicScale(mSize);
@@ -244,7 +250,7 @@ void iMarker::SetSize(const iDistance &s)
 void iMarker::SetCaptionText(const iString &s)
 {
 	mCaptionText = s;
-	mCaption->SetCaption(s.ToCharPointer());
+	mCaption->SetText(s);
 	if(s.Length() > 0) mCaption->VisibilityOn(); else mCaption->VisibilityOff();
 	this->ClearCache();
 }
