@@ -33,9 +33,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewfamily.h"
 
 
+class iColor;
+class iLegend;
 class iMarker;
+class iMarkerEventObserver;
 class iViewModule;
 
+class vtkPointWidget;
+
 
 class iMarkerFamily : public iViewFamily<iMarker,iViewModule>
 {
@@ -44,9 +49,36 @@ public:
 
 	static iMarkerFamily* New(iViewModule *vm);
 
+	virtual int CreateMember();
+	virtual bool DeleteMember(int i);
+
+	void ShowLegend(bool s);
+	bool IsLegendVisible();
+
+	void UpdateLegend();
+	void SetLegendPosition(int p);
+	inline int GetLegendPosition() const { return mLegendPosition; }
+
+	void SetHandlesColor(const iColor &c);
+	void ShowHandles(bool s);
+	bool IsHandlesVisible();
+
+protected:
+
+	virtual ~iMarkerFamily();
+
 private:
 
 	iMarkerFamily(iViewModule *vm);
+
+	void BuildLegend(int i = -2);
+	void UpdateEntry(int i);
+
+	int mLegendPosition;
+
+	iMarkerEventObserver *mMotionObserver;
+	vtkPointWidget *mHandles;
+	iLegend *mLegend;
 };
 
 #endif // IMARKERFAMILY_H
