@@ -30,10 +30,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IMEASURINGBOX_H
 
 
+#include "igenericprop.h"
 #include "iactor.h"
 
 
 #include "ipointermacro.h"
+#include "ivtk.h"
 
 #include <vtkProperty.h>
 
@@ -41,11 +43,13 @@ class iColor;
 class iTextActor;
 class iViewModule;
 
+class vtkCommand;
 class vtkCubeSource;
+class vtkInteractorStyle;
 class vtkPolyDataMapper;
 
 
-class iMeasuringBox : public iActor
+class iMeasuringBox : public iGenericProp<iActor>
 {
 	
 	IPOINTER_AS_PART(ViewModule);
@@ -55,37 +59,32 @@ public:
 	vtkTypeMacro(iMeasuringBox,iActor);
 	static iMeasuringBox* New(iViewModule *vm = 0);
 	
-	virtual void ReleaseGraphicsResources(vtkWindow *win);
+	void AttachToInteractorStyle(vtkInteractorStyle *s);
 
-	virtual int RenderOverlay(vtkViewport *vp);
-	virtual int RenderOpaqueGeometry(vtkViewport *vp);
-	virtual int RenderTranslucentGeometry(vtkViewport *vp);
+	void SetSize(float s);
+	void SetOpacity(float s);
+	void SetColor(iColor &c);
+	void SetBaseScale(float s);
 
-	virtual void SetSize(float s){ if(s > 0.0){ mSize = s; this->Modified(); } }
-	virtual void SetOpacity(float s);
-	virtual void SetColor(iColor &c);
-	virtual void SetBaseScale(float s);
-
-	inline float GetOpacity(){ return this->GetProperty()->GetOpacity(); }
+	inline float GetOpacity(){ return mBoxActor->GetProperty()->GetOpacity(); }
 	inline float GetSize(){ return mSize; }
 	
-	virtual iTextActor *GetTextActor(){ return mText; }
-
 	virtual double *GetBounds(){ return 0; }  // Set to zero so that the text is always displayed
-	virtual float GetLength();
 
 protected:
 	
 	virtual ~iMeasuringBox();
 	
+	virtual void UpdateGeometry(vtkViewport *vp);
+
 private:
 
 	iMeasuringBox(iViewModule *vm);
 
-	vtkCubeSource *mCube;
-	iActor *mFrame;
-
 	iTextActor *mText;
+	iActor *mFrameActor, *mBoxActor, *mWorkerActor;
+
+	vtkCommand *mObserver;
 
 	bool mStarted;
 	float mSize, mBaseScale;
