@@ -29,11 +29,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iorthotextureplanefilter.h"
 
 
+#include "idatalimits.h"
 #include "ierror.h"
 #include "iorthoslicer.h"
 #include "imath.h"
 
 #include <vtkCellArray.h>
+#include <vtkCellData.h>
 #include <vtkPointData.h>
 #include <vtkStructuredPoints.h>
 
@@ -72,6 +74,31 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 
 	if(mTexture == 0) return;
 
+	//
+	//  Do we have cell or point data?
+	//
+	vtkFloatArray *scalars;
+	bool isPointData;
+	if(input->GetPointData()->GetScalars() != 0)
+	{
+		isPointData = true;
+		scalars = vtkFloatArray::SafeDownCast(input->GetPointData()->GetScalars());
+	}
+	else if(input->GetCellData()->GetScalars() != 0)
+	{
+		isPointData = false;
+		scalars = vtkFloatArray::SafeDownCast(input->GetCellData()->GetScalars());
+	}
+	else
+	{
+		//
+		//  Must be quiet here for parallel execution
+		//
+		return;
+	}
+
+	if(scalars == 0) return;
+
 	//
 	//  Prepare texture support
 	//
@@ -86,20 +113,36 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 	}
 	if(Axis == -1) return;
 
-    int Uidx, Vidx;
-	iOrthoSlicer::GetUV(Axis,Uidx,Vidx);
+    int u, v, dimU, dimV;
+	iOrthoSlicer::GetUV(Axis,u,v);
+
+	if(isPointData)
+	{
+		dimU = dims[u] - 1;
+		dimV = dims[v] - 1;
+	}
+	else
+	{
+		dimU = dims[u];
+		dimV = dims[v];
+	}
+
+	if(dimU<1 || dimV<1)
+	{
+		return;
+	}
 
 	mTexture->GetDimensions(dimsTexture);
 
-	float tc[2];
-	static vtkIdType pts[4]={0,1,2,3};
-
 	//
-	//  AppenPolyDataFilter does not merge texture coordinates into one, so we need to create the correct texture support here.
+	//  AppendPolyDataFilter does not merge texture coordinates into one, so we need to create the correct texture support here.
 	//  We create it for zero offset instance, and skip it altogether for other instances.
 	//
 	if(mOffX==0 && mOffY==0)
 	{
+		float tc[2];
+		static vtkIdType pts[4]={0,1,2,3};
+
 		//
 		// We'll create the building blocks of polydata including data attributes.
 		//
@@ -129,8 +172,8 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 		//
 		//  LL point 
 		//
-		x1[Uidx] = org[Uidx];
-		x1[Vidx] = org[Vidx];
+		x1[u] = org[u];
+		x1[v] = org[v];
 		points->SetPoint(0,x1);
 		tc[0] = 0.0;
 		tc[1] = 0.0;
@@ -138,29 +181,29 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 		//
 		//  LR point 
 		//
-		x1[Uidx] = org[Uidx] + spa[Uidx]*dimsTexture[0];
-		x1[Vidx] = org[Vidx];
+		x1[u] = org[u] + spa[u]*dimU;
+		x1[v] = org[v];
 		points->SetPoint(1,x1);
-		tc[0] = 1.0;
+		tc[0] = float(dimU)/dimsTexture[0];
 		tc[1] = 0.0;
 		tcoords->SetTuple(1,tc);
 		//
 		//  UR point 
 		//
-		x1[Uidx] = org[Uidx] + spa[Uidx]*dimsTexture[0];
-		x1[Vidx] = org[Vidx] + spa[Vidx]*dimsTexture[1];
+		x1[u] = org[u] + spa[u]*dimU;
+		x1[v] = org[v] + spa[v]*dimV;
 		points->SetPoint(2,x1);
-		tc[0] = 1.0;
-		tc[1] = 1.0;
+		tc[0] = float(dimU)/dimsTexture[0];
+		tc[1] = float(dimV)/dimsTexture[1];
 		tcoords->SetTuple(2,tc);
 		//
 		//  UL point 
 		//
-		x1[Uidx] = org[Uidx];
-		x1[Vidx] = org[Vidx] + spa[Vidx]*dimsTexture[1];
+		x1[u] = org[u];
+		x1[v] = org[v] + spa[v]*dimV;
 		points->SetPoint(3,x1);
 		tc[0] = 0.0;
-		tc[1] = 1.0;
+		tc[1] = float(dimV)/dimsTexture[1];
 		tcoords->SetTuple(3,tc);
 
 		//
@@ -175,10 +218,10 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 	}
 
 	//
-	//  Fill in out portion of the texture
+	//  Fill in our portion of the texture
 	//
- 	int ncomIn = input->GetPointData()->GetScalars()->GetNumberOfComponents();
-    float *ptrIn = (float *)input->GetScalarPointer();
+ 	int ncomIn = scalars->GetNumberOfComponents();
+    float *ptrIn = scalars->GetPointer(0);
 	float *ptrOut = (float *)mTexture->GetScalarPointer();
 
 	if(ptrOut == 0)
@@ -191,15 +234,15 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 
 	ijk[Axis] = 0;
 
-	ijkmin[Uidx] = 0;
-	ijkmin[Vidx] = 0;
-	ijknum[Uidx] = dims[Uidx] - 1;
-	ijknum[Vidx] = dims[Vidx] - 1;
+	ijkmin[u] = 0;
+	ijkmin[v] = 0;
+	ijknum[u] = dimU;
+	ijknum[v] = dimV;
 
-	if(mOffX < 0) ijkmin[Uidx] -= mOffX;
-	if(mOffY < 0) ijkmin[Vidx] -= mOffY;
-	if(mOffX+ijknum[Uidx] > dimsTexture[0]) ijknum[Uidx] = dimsTexture[0] - mOffX;
-	if(mOffY+ijknum[Vidx] > dimsTexture[1]) ijknum[Vidx] = dimsTexture[1] - mOffY;
+	if(mOffX < 0) ijkmin[u] -= mOffX;
+	if(mOffY < 0) ijkmin[v] -= mOffY;
+	if(mOffX+ijknum[u] > dimsTexture[0]) ijknum[u] = dimsTexture[0] - mOffX;
+	if(mOffY+ijknum[v] > dimsTexture[1]) ijknum[v] = dimsTexture[1] - mOffY;
 
 	vtkIdType off1 = 0, off2 = 0, off3;
 	switch(Axis)
@@ -207,7 +250,7 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 	case 0:
 		{
 			//
-			//  Uidx = 1, Vidx = 2;
+			//  u = 1, v = 2;
 			//
 			off1 = dims[0];
 			off2 = dims[0]*dims[1];
@@ -216,7 +259,7 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 	case 1:
 		{
 			//
-			//  Uidx = 0, Vidx = 1;
+			//  u = 0, v = 1;
 			//
 			off1 = 1;
 			off2 = dims[0]*dims[1];
@@ -225,7 +268,7 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 	case 2:
 		{
 			//
-			//  Uidx = 0, Vidx = 1;
+			//  u = 0, v = 1;
 			//
 			off1 = 1;
 			off2 = dims[0];
@@ -238,17 +281,141 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 	off3 = off1 + off2;
 
 	vtkIdType lIn, lOut;
-	for(ijk[Vidx]=ijkmin[Vidx]; ijk[Vidx]<ijknum[Vidx]; ijk[Vidx]++)
+	for(ijk[v]=ijkmin[v]; ijk[v]<ijknum[v]; ijk[v]++)
 	{
-		this->UpdateProgress((float)(ijk[Vidx]-ijkmin[Vidx])/(ijknum[Vidx]-ijkmin[Vidx]+1));
+		this->UpdateProgress((float)(ijk[v]-ijkmin[v])/(ijknum[v]-ijkmin[v]));
 		if(this->GetAbortExecute()) break;
 
-		for(ijk[Uidx]=ijkmin[Uidx]; ijk[Uidx]<ijknum[Uidx]; ijk[Uidx]++)
+		for(ijk[u]=ijkmin[u]; ijk[u]<ijknum[u]; ijk[u]++)
 		{
 			lIn = ncomIn*(ijk[0]+dims[0]*(ijk[1]+(vtkIdType)dims[1]*ijk[2]));
-			lOut = mOffX + ijk[Uidx] + dimsTexture[0]*(mOffY+ijk[Vidx]);
-			ptrOut[lOut] = 0.25f*(ptrIn[lIn]+ptrIn[lIn+off1]+ptrIn[lIn+off2]+ptrIn[lIn+off3]);
-//			ptrOut[lOut] = pow10(-0.1*float(ijk[Uidx]));
+			lOut = mOffX + ijk[u] + dimsTexture[0]*(mOffY+ijk[v]);
+			if(isPointData)
+			{
+				ptrOut[lOut] = 0.25f*(ptrIn[lIn]+ptrIn[lIn+off1]+ptrIn[lIn+off2]+ptrIn[lIn+off3]);
+			}
+			else
+			{
+				ptrOut[lOut] = ptrIn[lIn];
+			}
+//			ptrOut[lOut] = pow10(-0.1*float(ijk[u]));
+		}
+	}
+	mTexture->Modified();
+}
+
+
+void iOrthoTexturePlaneFilter::UpdateBoundaryConditions()
+{
+	//
+	//  Do it only for master
+	//
+	if(mTexture==0 || mOffX!=0 || mOffY!=0) return;
+
+	int dims[3], dimsTexture[3];
+	vtkImageData *input = this->GetInput();
+
+	//
+	//  Do we have cell or point data?
+	//
+	bool isPointData;
+	if(input->GetPointData()->GetScalars() != 0)
+	{
+		isPointData = true;
+	}
+	else if(input->GetCellData()->GetScalars() != 0)
+	{
+		isPointData = false;
+	}
+	else
+	{
+		//
+		//  Must be quiet here for parallel execution
+		//
+		return;
+	}
+
+	input->GetDimensions(dims);
+
+	int i, Axis = -1;
+	for(i=0; i<3; i++)
+	{
+		if(dims[i] == 1) Axis = i;
+	}
+	if(Axis == -1) return;
+
+    int u, v, dimU, dimV;
+	iOrthoSlicer::GetUV(Axis,u,v);
+
+	if(isPointData)
+	{
+		dimU = dims[u] - 1;
+		dimV = dims[v] - 1;
+	}
+	else
+	{
+		dimU = dims[u];
+		dimV = dims[v];
+	}
+
+	if(dimU<1 || dimV<1)
+	{
+		return;
+	}
+
+	mTexture->GetDimensions(dimsTexture);
+
+	float *ptrOut = (float *)mTexture->GetScalarPointer();
+
+	//
+	//  Boundary conditions for proper interpolation
+	//
+	int i1off, i2off;
+	bool per[3];
+	this->GetLimits()->GetPeriodicities(per);
+
+	if(dimU < dimsTexture[0])
+	{
+		i1off = per[u] ? dimU-1 : 0;
+		i2off = per[u] ? 0 : dimU-1;
+
+		for(i=0; i<dimV; i++)
+		{
+			ptrOut[dimsTexture[0]-1+dimsTexture[0]*i] = ptrOut[i1off+dimsTexture[0]*i];
+			ptrOut[dimU+dimsTexture[0]*i] = ptrOut[i2off+dimsTexture[0]*i];
+		}
+	}
+
+	if(dimV < dimsTexture[1])
+	{
+		i1off = per[v] ? dimV-1 : 0;
+		i2off = per[v] ? 0 : dimV-1;
+
+		for(i=0; i<dimU; i++)
+		{
+			ptrOut[i+dimsTexture[0]*(dimsTexture[1]-1)] = ptrOut[i+dimsTexture[0]*i1off];
+			ptrOut[i+dimsTexture[0]*dimV] = ptrOut[i+dimsTexture[0]*i2off];
+		}
+	}
+
+	//
+	//  Corners
+	//
+	if(dimU<dimsTexture[0] && dimV<dimsTexture[1])
+	{
+		if(per[u] && per[v])
+		{
+			ptrOut[dimU+dimsTexture[0]*dimV] = ptrOut[0+dimsTexture[0]*0];
+			ptrOut[dimU+dimsTexture[0]*(dimsTexture[1]-1)] = ptrOut[+dimsTexture[0]*(dimV-1)];
+			ptrOut[dimsTexture[0]-1+dimsTexture[0]*dimV] = ptrOut[dimU-1+dimsTexture[0]*0];
+			ptrOut[dimsTexture[0]-1+dimsTexture[0]*(dimsTexture[1]-1)] = ptrOut[dimU-1+dimsTexture[0]*(dimV-1)];
+		}
+		else
+		{
+			ptrOut[dimU+dimsTexture[0]*dimV] = 0.5f*(ptrOut[dimU-1+dimsTexture[0]*dimV]+ptrOut[dimU+dimsTexture[0]*(dimV-1)]);
+			ptrOut[dimU+dimsTexture[0]*(dimsTexture[1]-1)] = 0.5f*(ptrOut[dimU-1+dimsTexture[0]*(dimsTexture[1]-1)]+ptrOut[dimU+dimsTexture[0]*0]);
+			ptrOut[dimsTexture[0]-1+dimsTexture[0]*dimV] = 0.5f*(ptrOut[dimsTexture[0]-1+dimsTexture[0]*(dimV-1)]+ptrOut[0+dimsTexture[0]*dimV]);
+			ptrOut[dimsTexture[0]-1+dimsTexture[0]*(dimsTexture[1]-1)] = 0.5f*(ptrOut[0+dimsTexture[0]*(dimsTexture[1]-1)]+ptrOut[dimsTexture[0]-1+dimsTexture[0]*0]);
 		}
 	}
 
