@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iOrthoTexturePlaneFilter : public iGenericFilter<vtkStructuredPointsToPolyDataFilter,vtkImageData,vtkPolyData>
 {
 
-	IGENERICFILTER_DECLARE(iOrthoTexturePlaneFilter);
+	IGENERICFILTER_DECLARE(iOrthoTexturePlaneFilter,vtkStructuredPointsToPolyDataFilter);
 
 public: 
 
@@ -46,10 +46,14 @@ public:
 	//
 	void SetTexturePiece(vtkImageData *texture, int offX, int offY);
 
+	void UpdateBoundaryConditions();
+
 protected:
 
 	virtual void ProduceOutput();
 
+private:
+
 	vtkImageData *mTexture;
 	int mOffX, mOffY;
 };
