@@ -309,7 +309,7 @@ void iOutputChannel::UpdateLog(const iString &message, const char* file, int lin
 	
 		if(!mLogCreated)
 		{
-#ifdef IVTK_4
+#ifdef IVTK_44
 			double s = vtkTimerLog::GetCurrentTime();
 #else
 			double s = vtkTimerLog::GetUniversalTime();
@@ -380,7 +380,9 @@ void iOutputChannel::DisplayBody(iConsole::MessageType type, const iString &mess
 	//
 	//  Send everything to the standard vtkOutputWindow
 	//
+	if(type == iConsole::_Notification) vtkOutputWindow::GetInstance()->PromptUserOn();
 	vtkOutputWindow::GetInstance()->DisplayText(this->FormPlainTextMessage(type,message,file,line).ToCharPointer());
+	vtkOutputWindow::GetInstance()->PromptUserOff();
 }
 
 
@@ -391,6 +393,7 @@ iString iOutputChannel::FormPlainTextMessage(iConsole::MessageType type, const i
 	switch(type)
 	{
 	case iConsole::_Info:
+	case iConsole::_Notification:
 		{
 			text = message + "\n";
 			break;
