@@ -249,7 +249,7 @@ void iParticleConnector::ProduceOutput()
 
 	if(mAttCon==-1 || input->GetPointData()->GetScalars()==0 || mAttSep==mAttCon) return;
 
-	vtkFloatArray *inAtts = iRequiredCast<vtkFloatArray>(input->GetPointData()->GetScalars());
+	vtkFloatArray *inAtts = iRequiredCast<vtkFloatArray>(INFO,input->GetPointData()->GetScalars());
 	vtkIdType np = input->GetNumberOfPoints();
 	vtkIdType nc = inAtts->GetNumberOfComponents();
 
@@ -270,7 +270,7 @@ void iParticleConnector::ProduceOutput()
 #ifdef I_CHECK2
 		for(l=0; l<np-1; l++) if(GREATER1(ind[l],ind[l+1]))
 		{
-			IERROR_REPORT("Error in Index1.");
+			IERROR_LOW("Error in Index1.");
 			break;
 		}
 #endif
@@ -292,7 +292,7 @@ void iParticleConnector::ProduceOutput()
 #ifdef I_CHECK2
 		for(l=0; l<np-1; l++) if(GREATER2(ind[l],ind[l+1]))
 		{
-			IERROR_REPORT("Error in Index2.");
+			IERROR_LOW("Error in Index2.");
 			break;
 		}
 #endif
