@@ -995,7 +995,7 @@ void iParticleHelper::AutoScalePositions()
 			for(i=0; i<3; i++)
 			{
 				if(ptr[3*l+i] < min[i]) min[i] = ptr[3*l+i];
-				if(ptr[3*l+i] < max[i]) max[i] = ptr[3*l+i];
+				if(ptr[3*l+i] > max[i]) max[i] = ptr[3*l+i];
 			}
 		}
 
@@ -1019,7 +1019,7 @@ void iParticleHelper::AutoScalePositions()
 		{
 			for(i=0; i<3; i++)
 			{
-				ptr[i] = -1.0 + r*(ptr[i]-min[i]);
+				ptr[3*l+i] = -1.0 + r*(ptr[3*l+i]-min[i]);
 			}
 		}
 	}
