@@ -29,6 +29,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iparticlegroup.h"
 
 
+#include "iartifactcorrector.h"
 #include "icommondatadistributors.h"
 #include "icommoneventobservers.h"
 #include "icontrolmodule.h"
@@ -53,6 +54,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkPolyData.h>
 #include <vtkProperty.h>
 #include <vtkRenderer.h>
+#include <vtkRenderWindow.h>
 
 //
 //  Templates (needed for some compilers)
@@ -205,6 +207,35 @@ namespace iParticleGroup_Private
 		iParticleGroup *mParent;
 		double mReferenceSize, mParallelScale, mDistance;
 	};
+
+	//
+	//  Correct antialising artifact for opaque particles
+	//
+	class ArtifactCorrector : public iArtifactCorrector
+	{
+
+		IGENERICFILTER_DECLARE(ArtifactCorrector,iArtifactCorrector);
+
+	protected:
+
+		virtual bool HasArtifacts(vtkRenderer *ren, vtkProperty *prop)
+		{
+			vtkPolyData *output = this->GetOutput();
+
+			//
+			//  Activate for antialiased opaque verts
+			//
+			if(output->GetNumberOfVerts()>0 && prop!=0 && ren->GetRenderWindow()!=0)
+			{
+				return (prop->GetOpacity()==1.0 && ren->GetRenderWindow()->GetPointSmoothing()!=0);
+			}
+			else return false;
+		}
+	};
+
+	ArtifactCorrector::ArtifactCorrector(iViewSubject *vo) : iArtifactCorrector(vo)
+	{
+	}
 }
 
 
@@ -220,7 +251,7 @@ iParticleGroup* iParticleGroup::New(iParticlesViewSubject *parent)
 }
 
 
-iParticleGroup::iParticleGroup(iParticlesViewSubject *parent) : iSolidViewSubject(parent->GetViewModule(),parent->GetDataType(),parent->GetObjectName(),2,_ViewSubjectSameColor|_ViewSubjectSameOpacity|_ViewSubjectSamePalette)
+iParticleGroup::iParticleGroup(iParticlesViewSubject *parent) : iSolidViewSubject(parent->GetViewModule(),parent->GetDataType(),parent->GetObjectName(),2,_ViewSubjectSameColor|_ViewSubjectSameOpacity|_ViewSubjectSamePalette,0.999)
 {
 	mObjectType = _ObjectTypeParticles;
 
@@ -261,6 +292,10 @@ iParticleGroup::iParticleGroup(iParticlesViewSubject *parent) : iSolidViewSubjec
 	mActors[1]->VisibilityOff();
 	mActors[1]->PickableOff();
 
+	ArtifactCorrector *ac =	ArtifactCorrector::New(this); IERROR_ASSERT(ac);
+	mActors[0]->InstallArtifactCorrector(ac);
+	ac->Delete();
+
 	this->SetColor(0,iColor(0,0,0));
 }
 
