@@ -276,9 +276,9 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	//
 	if(ren == 0)
 	{
-		mStereoAlignmentMarkersActor = vtkPropAssembly::New(); IERROR_ASSERT(mStereoAlignmentMarkersActor);
-		mStereoAlignmentMarkersActor->VisibilityOff();
-		mStereoAlignmentMarkersActor->PickableOff();
+		mStereoAlignmentMarksActor = vtkPropAssembly::New(); IERROR_ASSERT(mStereoAlignmentMarksActor);
+		mStereoAlignmentMarksActor->VisibilityOff();
+		mStereoAlignmentMarksActor->PickableOff();
 		vtkPolyDataMapper2D *mapper2D = vtkPolyDataMapper2D::New(); IERROR_ASSERT(mapper2D);
 		vtkLineSource *ls;
 		vtkActor2D *actor2D[8];
@@ -312,20 +312,20 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 			actor2D[i]->SetMapper(mapper2D);
 			mapper2D->Delete();
 			actor2D[i]->GetProperty()->SetColor(0.0,0.0,0.0);
-			actor2D[i]->GetPositionCoordinate()->SetCoordinateSystemToNormalizedDisplay();
+			actor2D[i]->GetPositionCoordinate()->SetCoordinateSystemToNormalizedViewport();
 			actor2D[i]->PickableOff();	
 			actor2D[i]->SetPosition((0.5-amo)*(2*((i/2)%2)-1),(0.5-amo)*(2*((i/4)%2)-1));
 			actor2D[i]->SetLayerNumber(1);
-			mStereoAlignmentMarkersActor->AddPart(actor2D[i]);
+			mStereoAlignmentMarksActor->AddPart(actor2D[i]);
 			actor2D[i]->Delete();
 		}
 
-		this->AddObject(mStereoAlignmentMarkersActor);
-		mStereoAlignmentMarkersActor->Delete();
+		this->AddObject(mStereoAlignmentMarksActor);
+		mStereoAlignmentMarksActor->Delete();
 	}
 	else
 	{
-		mStereoAlignmentMarkersActor = 0;
+		mStereoAlignmentMarksActor = 0;
 	}
 
 	//
@@ -346,14 +346,16 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	//  Properties
 	//
 	mStereoType = -1;
-	mAntialiasing = false;
-	mStereoAlignmentMarkersOn = true;
+	mAntialiasing = mBackgroundImageFixedAspect = false;
+	mStereoAlignmentMarksOn = true;
 
 	//
 	//  Set the properties
 	//
+	mFontScale = 0;
+	mFontType = iParameter::_TextTypeBitmapArial;
 	this->SetStereoType(VTK_STEREO_RED_BLUE);
-	this->SetAntialiasing(true);
+	//this->SetAntialiasing(true);
 }
 
 
@@ -522,7 +524,7 @@ void iRenderTool::AddObject(vtkProp* p)
 	if(p->IsA("vtkVolume") != 0)
 	{
 		mVolumeObjects->AddItem(p);
-#ifdef IVTK_4
+#ifdef IVTK_44
 		mMainRen->AddProp(p);
 		mDualRen->AddProp(p);
 #else
@@ -537,7 +539,7 @@ void iRenderTool::AddObject(vtkProp* p)
 		//
 		mActorObjects->AddItem(p);
 
-#ifdef IVTK_4
+#ifdef IVTK_44
 		mMainRen->RemoveAllProps();
 		mDualRen->RemoveAllProps();
 #else
@@ -549,7 +551,7 @@ void iRenderTool::AddObject(vtkProp* p)
 		mActorObjects->InitTraversal();
 		while((p = mActorObjects->GetNextProp()) != 0)
 		{
-#ifdef IVTK_4
+#ifdef IVTK_44
 			mMainRen->AddProp(p);
 			mDualRen->AddProp(p);
 #else
@@ -560,7 +562,7 @@ void iRenderTool::AddObject(vtkProp* p)
 		mVolumeObjects->InitTraversal();
 		while((p = mVolumeObjects->GetNextProp()) != 0)
 		{
-#ifdef IVTK_4
+#ifdef IVTK_44
 			mMainRen->AddProp(p);
 			mDualRen->AddProp(p);
 #else
@@ -585,7 +587,7 @@ void iRenderTool::RemoveObject(vtkProp* p)
 		mActorObjects->RemoveItem(p);
 	}
 
-#ifdef IVTK_4
+#ifdef IVTK_44
 	mMainRen->RemoveProp(p);
 	mDualRen->RemoveProp(p);
 #else
@@ -646,7 +648,7 @@ void iRenderTool::SetAntialiasing(bool s)
 
 #ifndef I_OFFSCREEN
 	vtkOpenGLRenderWindow *w = vtkOpenGLRenderWindow::SafeDownCast(mMainWin);
-	if(w != 0)
+	if(w!=0 && w->GetNeverRendered()==0)
 	{
 		w->MakeCurrent();
 		w->OpenGLInit();
@@ -654,7 +656,7 @@ void iRenderTool::SetAntialiasing(bool s)
 	if(mDualWin != 0)
 	{
 		w = vtkOpenGLRenderWindow::SafeDownCast(mDualWin);
-		if(w != 0)
+		if(w!=0 && w->GetNeverRendered()==0)
 		{
 			w->MakeCurrent();
 			w->OpenGLInit();
@@ -670,6 +672,37 @@ void iRenderTool::SetAdjustCameraClippingRangeAutomatically(bool s)
 }
 
 
+void iRenderTool::SetBackgroundImageFixedAspect(bool s)
+{
+	if(mBackgroundImageFixedAspect != s)
+	{
+		mBackgroundImageFixedAspect = s;
+		mMainBkg->SetImageFixedAspect(s);
+		mDualBkg->SetImageFixedAspect(s);
+	}
+}
+
+
+void iRenderTool::SetBackgroundImageTile(float tx, float ty, float tw, float th)
+{
+	float tile[4];
+
+	tile[0] = tx;
+	tile[1] = ty;
+	tile[2] = tw;
+	tile[3] = th;
+
+	this->SetBackgroundImageTile(tile);
+}
+
+
+void iRenderTool::SetBackgroundImageTile(const float tile[4])
+{
+	mMainBkg->SetImageTile(tile);
+	mDualBkg->SetImageTile(tile);
+}
+
+
 void iRenderTool::SetCameraClippingRange(double cr[2])
 {
 	//
@@ -699,10 +732,10 @@ void iRenderTool::RenderStereoImage(int mag, iStereoImage &image)
 	int v = 0;
 
 	mDualWindowObserver->Block(true);
-	if(mStereoAlignmentMarkersActor != 0)
+	if(mStereoAlignmentMarksActor != 0)
 	{
-		v = mStereoAlignmentMarkersActor->GetVisibility();
-		mStereoAlignmentMarkersActor->VisibilityOff();
+		v = mStereoAlignmentMarksActor->GetVisibility();
+		mStereoAlignmentMarksActor->VisibilityOff();
 	}
 
 	mMagnifier->SetMagnification(mag);
@@ -732,9 +765,9 @@ void iRenderTool::RenderStereoImage(int mag, iStereoImage &image)
 
 	mMagnifier->SetMagnification(1);
 
-	if(mStereoAlignmentMarkersActor != 0)
+	if(mStereoAlignmentMarksActor != 0)
 	{
-		mStereoAlignmentMarkersActor->SetVisibility(v);
+		mStereoAlignmentMarksActor->SetVisibility(v);
 	}
 	mDualWindowObserver->Block(false);
 }
@@ -757,10 +790,10 @@ void iRenderTool::GetAspectRatio(double ar[2]) const
 //
 //  Stereo operations
 //
-void iRenderTool::ShowStereoAlignmentMarkers(bool s)
+void iRenderTool::ShowStereoAlignmentMarks(bool s)
 {
-	mStereoAlignmentMarkersOn = s;
-	mStereoAlignmentMarkersActor->SetVisibility((s && mDualWin!=0)?1:0);
+	mStereoAlignmentMarksOn = s;
+	mStereoAlignmentMarksActor->SetVisibility((s && mDualWin!=0)?1:0);
 }
 
 
@@ -834,7 +867,7 @@ void iRenderTool::ShowDualWindow(bool s)
 			mDualWin->AddRenderer(mDualBkg->GetRenderer());
 			mDualWin->AddRenderer(mDualRen);
 	
-			if(mStereoAlignmentMarkersActor!=0 && mStereoAlignmentMarkersOn) mStereoAlignmentMarkersActor->VisibilityOn();
+			if(mStereoAlignmentMarksActor!=0 && mStereoAlignmentMarksOn) mStereoAlignmentMarksActor->VisibilityOn();
 			this->GetViewModule()->UpdateWindowNumber();
 		}
 	}
@@ -850,7 +883,7 @@ void iRenderTool::ShowDualWindow(bool s)
 			mDualWin->Delete();
 			mDualWin = 0;
 
-			if(mStereoAlignmentMarkersActor != 0) mStereoAlignmentMarkersActor->VisibilityOff();
+			if(mStereoAlignmentMarksActor != 0) mStereoAlignmentMarksActor->VisibilityOff();
 			this->GetViewModule()->UpdateWindowNumber();
 		}
 	}
@@ -883,7 +916,7 @@ vtkRenderer* iRenderTool::CreateRenderer() const
 	//  so that iActors can create special mappers for this renderer. Otherwise, vtkPolyDataMappers 
 	//  remember the last window they rendered into, and will reset at switching to a different window.
 	//
-#ifdef IVTK_4
+#ifdef IVTK_44
 	vtkPropCollection *pc = mMainRen->GetProps();
 #else
 	vtkPropCollection *pc = mMainRen->GetViewProps();
@@ -892,7 +925,7 @@ vtkRenderer* iRenderTool::CreateRenderer() const
 	pc->InitTraversal();
 	while((p = pc->GetNextProp()) != 0)
 	{
-#ifdef IVTK_4
+#ifdef IVTK_44
 		ren->AddProp(p);
 #else
 		ren->AddViewProp(p);
@@ -925,3 +958,33 @@ int iRenderTool::GetFullScreenMode() const
 	return 1;
 }
 
+
+void iRenderTool::CopyBackground(const iRenderTool *source)
+{
+	if(source != 0)
+	{
+		mMainBkg->Copy(source->mMainBkg);
+		mDualBkg->Copy(source->mDualBkg);
+	}
+}
+
+
+void iRenderTool::SetFontScale(int s)
+{
+	if(s>-10 && s<10)
+	{
+		mFontScale = s; 
+	}
+}
+
+
+void iRenderTool::SetFontType(int s)
+{
+	if(s>=0 && s<iParameter::__NumTextTypes)
+	{
+		mFontType = s; 
+	}
+}
+
+
+
