@@ -30,77 +30,140 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
+#include "iimage.h"
 
 #include <vtkActor2D.h>
-#include <vtkImageData.h>
 #include <vtkImageMapper.h>
-#include <vtkImageResample.h>
 #include <vtkProperty2D.h>
 #include <vtkRenderer.h>
 
 
-namespace iRenderToolBackground_Private
+class iRenderToolBackgroundImageMapper : public vtkImageMapper
 {
-	class ImageMapper : public vtkImageMapper
+
+public:
+
+	static iRenderToolBackgroundImageMapper* New()
 	{
+		return new iRenderToolBackgroundImageMapper;
+	}
 
-	public:
+	virtual void RenderData(vtkViewport *, vtkImageData *, vtkActor2D *)
+	{
+	}
 
-		static ImageMapper* New()
-		{
-			return new ImageMapper;
-		}
-
-		virtual void RenderOverlay(vtkViewport *viewport, vtkActor2D *mActor)
-		{
-			this->RenderStart(viewport,mActor);
-		}
-
-		virtual void RenderData(vtkViewport *viewport, vtkImageData *data, vtkActor2D *mActor)
-		{
-			int dims[3], *size = viewport->GetSize();
-			data->GetDimensions(dims);
-
-			mFilter->SetInput(this->GetInput());
-
-			mFilter->SetAxisMagnificationFactor(0,float(size[0])/dims[0]);
-			mFilter->SetAxisMagnificationFactor(1,float(size[1])/dims[1]);
-
-			mFilter->Update();
-			mWorker->RenderOverlay(viewport,mActor);
-		}
-
-	protected:
+	virtual void RenderOverlay(vtkViewport *viewport, vtkActor2D *actor)
+	{
+		int *size = viewport->GetSize();
 		
-		ImageMapper()
+		if(this->GetMTime()>mBuildTime || size[0]!=mOldSize[0] || size[1]!=mOldSize[1])
 		{
-			mFilter = vtkImageResample::New(); IERROR_ASSERT(mFilter);
-			mWorker = vtkImageMapper::New(); IERROR_ASSERT(mWorker);
+			mOldSize[0] = size[0];
+			mOldSize[1] = size[1];
 
-			mWorker->SetColorWindow(255.0);
-			mWorker->SetColorLevel(127.5);
-			mWorker->RenderToRectangleOn();
-			mWorker->UseCustomExtentsOff();
-	
-			mFilter->SetDimensionality(2);
-			mWorker->SetInput(mFilter->GetOutput());
+			mImageTile = mImageFull;;
+
+			if(mTile[0]>0.0 || mTile[2]<1.0 || mTile[1]>0.0 || mTile[3]<1.0)
+			{
+				int fw = mImageFull.Width();
+				int fh = mImageFull.Height();
+				
+				if(mFixedAspect)
+				{
+					float sx = float(fw)/size[0];
+					float sy = float(fh)/size[1];
+
+					if(sx > sy)
+					{
+						fw = round(sy*size[0]);
+					}
+					else
+					{
+						fh = round(sx*size[1]);
+					}
+				}
+				
+				int x = round(mTile[0]*fw); 
+				int w = round(mTile[2]*fw) - x;
+				int y = round(mTile[1]*fh);
+				int h = round(mTile[3]*fh) - y;
+
+				mImageTile.Crop(x,y,w,h);
+			}
+
+			mImageTile.Scale(size[0],size[1]);
+
+			mWorker->SetInput(mImageTile.DataObject());
+			mBuildTime.Modified();
 		}
 
-		~ImageMapper()
-		{
-			mFilter->Delete();
-			mWorker->Delete();
-		}
+		mWorker->RenderOverlay(viewport,actor);
+	}
 
-		vtkImageResample *mFilter;
-		vtkImageMapper *mWorker;
-	};
+	void SetImageFixedAspect(bool s)
+	{
+		if(mFixedAspect != s)
+		{
+			mFixedAspect = s;
+			this->Modified();
+		}
+	}
+
+	bool GetImageFixedAspect()
+	{
+		return mFixedAspect;
+	}
+
+	void SetImageTile(const float tile[4])
+	{
+		if(tile[0]!=mTile[0] || tile[1]!=mTile[1] || tile[2]!=mTile[2] || tile[3]!=mTile[3])
+		{
+			int j;
+			for(j=0; j<4; j++)
+			{
+				mTile[j] = tile[j];
+			}
+			this->Modified();
+		}
+	}
+
+	void SetImage(const iImage &im)
+	{
+		mImageFull = im;
+		this->Modified();
+	}
+
+protected:
+
+	iRenderToolBackgroundImageMapper()
+	{
+		mFixedAspect = false;
+		mTile[0] = mTile[1] = 0.0;
+		mTile[2] = mTile[3] = 1.0;
+		mOldSize[0] = mOldSize[1] = 0;
+
+		mWorker = vtkImageMapper::New(); IERROR_ASSERT(mWorker);
+		mWorker->SetColorWindow(255.0);
+		mWorker->SetColorLevel(127.5);
+		mWorker->RenderToRectangleOff();
+		mWorker->UseCustomExtentsOff();
+	}
+
+	~iRenderToolBackgroundImageMapper()
+	{
+		mWorker->Delete();
+	}
+
+	bool mFixedAspect;
+	float mTile[2], mMinExtent[2], mMaxExtent[2];
+	int mOldSize[2];
+
+	iImage mImageFull, mImageTile;
+	vtkImageMapper *mWorker;
+	vtkTimeStamp mBuildTime;
 };
 
 
-using namespace iRenderToolBackground_Private;
-
-
 //
 //  Main class
 //
@@ -115,7 +178,7 @@ iRenderToolBackground::iRenderToolBackground()
 	mRenderer = vtkRenderer::New(); IERROR_ASSERT(mRenderer);
 
 	mActor = vtkActor2D::New(); IERROR_ASSERT(mActor);
-	mMapper = ImageMapper::New(); IERROR_ASSERT(mMapper);
+	mMapper = iRenderToolBackgroundImageMapper::New(); IERROR_ASSERT(mMapper);
 
 	mMapper->SetColorWindow(255.0);
 	mMapper->SetColorLevel(127.5);
@@ -124,9 +187,9 @@ iRenderToolBackground::iRenderToolBackground()
 
 	mActor->SetMapper(mMapper);
 	mMapper->Delete();
-	mActor->GetPositionCoordinate()->SetCoordinateSystemToNormalizedDisplay();
+	mActor->GetPositionCoordinate()->SetCoordinateSystemToNormalizedViewport();
 	mActor->SetPosition(0.0,0.0);
-	mActor->GetPosition2Coordinate()->SetCoordinateSystemToNormalizedDisplay();
+	mActor->GetPosition2Coordinate()->SetCoordinateSystemToNormalizedViewport();
 	mActor->SetPosition2(1.0,1.0);
 	mActor->VisibilityOff();
 	mActor->PickableOff();
@@ -171,9 +234,32 @@ void iRenderToolBackground::SetImage(const iImage &image)
 		else
 		{
 			mImage = image;
-			mMapper->SetInput(mImage.DataObject());
+			mMapper->SetImage(mImage);
 			mActor->VisibilityOn();
 		}
 	}
 }
 
+
+void iRenderToolBackground::SetImageFixedAspect(bool s)
+{
+	mMapper->SetImageFixedAspect(s);
+}
+
+
+void iRenderToolBackground::SetImageTile(const float tile[4])
+{
+	mMapper->SetImageTile(tile);
+}
+
+
+void iRenderToolBackground::Copy(const iRenderToolBackground *source)
+{
+	if(source != 0)
+	{
+		this->SetColor(source->mColor);
+		this->SetImage(source->mImage);
+		mMapper->SetImageFixedAspect(source->mMapper->GetImageFixedAspect());
+	}
+}
+
