@@ -108,6 +108,7 @@ private:
 			{
 				mReplicas[k].Actor->Delete();
 				mReplicas.Remove(k);
+				k--;
 			}
 		}
 	}
@@ -136,14 +137,14 @@ private:
 //
 //  Main class
 //
-iReplicatedActor* iReplicatedActor::New(iViewSubjectReplicator *replicator, bool scaled)
+iReplicatedActor* iReplicatedActor::New(iViewSubject *vs, bool scaled)
 {
-	IERROR_ASSERT(replicator);
-	return new iReplicatedActor(replicator,scaled);
+	IERROR_ASSERT(vs);
+	return new iReplicatedActor(vs,scaled);
 }
 
 
-iReplicatedActor::iReplicatedActor(iViewSubjectReplicator *replicator, bool scaled) : iActor(scaled), iReplicated(replicator,false)
+iReplicatedActor::iReplicatedActor(iViewSubject *vs, bool scaled) : iActor(scaled), iReplicatedElement(false)
 {
 	//
 	//  Must create property first - it is not created by default
@@ -154,6 +155,7 @@ iReplicatedActor::iReplicatedActor(iViewSubjectReplicator *replicator, bool scal
 	//
 	this->Device->Delete();
 	this->Device = mRealDevice = iReplicatedActorDevice::New(this); IERROR_ASSERT(mRealDevice);
+	this->ReplicateAs(vs);
 }
 
 
