@@ -41,6 +41,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iparallelmanager.h"
 #include "ishellfactory.h"
 #include "iviewmodule.h"
+#include "ivtk.h"
 
 #include <vtkRenderWindow.h>
 #include <vtkTimerLog.h>
@@ -326,6 +327,17 @@ iShell* iShell::New(const iString &t, int argc, char **argv)
 		tmp->ConstructorBody(); 
 	}
 	//
+	//  Check that vtkIdType is 64-bit on a 64-bit machine
+	//
+	if(sizeof(vtkIdType)==4 && sizeof(long)==8)
+	{
+		iConsole::Display(iConsole::_Notification,"This machine is 64-bit, but VTK has been compiled with 32-bit ids.\n"
+			                                      "    This configuration is inconsistent and is prone to crashes.   \n"
+												  "       It is highly recommended that you recompile VTK with       \n"
+												  "           advanced option VTK_USE_64BIT_IDS set to ON            \n"
+												  "                    and then recompile IFrIT.                     ");
+	}
+	//
 	//   Load widget info into ObjectKeyHelp objects.
 	//
 #ifdef I_DEBUG
@@ -734,7 +746,7 @@ namespace iShell_Private
 		//
 		//  Check that sizes of basic types are correct
 		//
-		if(sizeof(int)!=4 || sizeof(float)!=4 || sizeof(double)!=8)
+		if(sizeof(int)!=4 || sizeof(float)!=4 || sizeof(double)!=8 || sizeof(void*)!=sizeof(long))
 		{
 			iConsole::Display(iConsole::_HighError,"IFrIT has not been ported to this machine.");
 			exit(0);
