@@ -133,9 +133,13 @@ void iSmoothPolyDataFilter::ProduceOutput()
 		return;
 	}
 
-	CosFeatureAngle = 
-		cos((double) vtkMath::DegreesToRadians() * this->FeatureAngle);
+#ifdef IVTK_PRE54
+	CosFeatureAngle = cos((double) vtkMath::DegreesToRadians() * this->FeatureAngle);
 	CosEdgeAngle = cos((double) vtkMath::DegreesToRadians() * this->EdgeAngle);
+#else
+	CosFeatureAngle = cos(vtkMath::RadiansFromDegrees(this->FeatureAngle));
+	CosEdgeAngle = cos(vtkMath::RadiansFromDegrees(this->EdgeAngle));
+#endif
 
 	vtkDebugMacro(<<"Smoothing " << numPts << " vertices, " << numCells 
 		<< " cells with:\n"
