@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iSmoothPolyDataFilter : public iGenericPolyDataToPolyDataFilter<vtkWindowedSincPolyDataFilter>
 {
 	
-	IGENERICFILTER_DECLARE(iSmoothPolyDataFilter);
+	IGENERICFILTER_DECLARE(iSmoothPolyDataFilter,vtkWindowedSincPolyDataFilter);
 	
 protected:
 	
