@@ -39,7 +39,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ireplicatedactor.h"
 #include "iviewmodule.h"
 #include "iviewsubjectobserver.h"
-#include "iviewsubjectreplicator.h"
 
 #include <vtkProperty.h>
 
@@ -67,7 +66,7 @@ IOBJECT_DEFINE_KEY(iSolidViewSubject,Palette,p,Int,0);
 //
 // Main class
 //
-iSolidViewSubject::iSolidViewSubject(iViewModule *vm, const iDataType &type, const iString &name, int numActors, unsigned int flags) : iViewSubject(vm,type,name,flags), mNoColor((flags&_ViewSubjectNoColor)!=0U), mNoOpacity((flags&_ViewSubjectNoOpacity)!=0U), mNoPalette((flags&_ViewSubjectNoPalette)!=0U), mSameColor((flags&_ViewSubjectSameColor)!=0U), mSameOpacity((flags&_ViewSubjectSameOpacity)!=0U), mSamePalette((flags&_ViewSubjectSamePalette)!=0U)
+iSolidViewSubject::iSolidViewSubject(iViewModule *vm, const iDataType &type, const iString &name, int numActors, unsigned int flags, float maxOpacity) : iViewSubject(vm,type,name,flags), mNoColor((flags&_ViewSubjectNoColor)!=0U), mNoOpacity((flags&_ViewSubjectNoOpacity)!=0U), mNoPalette((flags&_ViewSubjectNoPalette)!=0U), mSameColor((flags&_ViewSubjectSameColor)!=0U), mSameOpacity((flags&_ViewSubjectSameOpacity)!=0U), mSamePalette((flags&_ViewSubjectSamePalette)!=0U), mMaxOpacity(maxOpacity)
 {
 	int i;
 
@@ -90,7 +89,7 @@ iSolidViewSubject::iSolidViewSubject(iViewModule *vm, const iDataType &type, con
 		}
 		else
 		{
-			a = iReplicatedActor::New(mReplicator); IERROR_ASSERT(a);
+			a = iReplicatedActor::New(this); IERROR_ASSERT(a);
 		}
 		a->SetScalarVisibility(false);
 		a->GetLookupTable()->SetPalette(this->GetViewModule()->GetControlModule()->GetPalette(0));
@@ -98,7 +97,7 @@ iSolidViewSubject::iSolidViewSubject(iViewModule *vm, const iDataType &type, con
 		a->ColorByArrayComponent(0,0); 
 		a->SetPosition(0.0,0.0,0.0);
 		a->VisibilityOff();
-		a->GetProperty()->SetOpacity(1.0);
+		a->GetProperty()->SetOpacity(mMaxOpacity);
 		a->GetProperty()->SetInterpolationToGouraud();
 		a->GetProperty()->SetColor(mDefaultColor.ToVTK());
 		a->AddMapperObserver(vtkCommand::ProgressEvent,obsAbortRender);
@@ -207,7 +206,7 @@ void iSolidViewSubject::SetOpacity(int l, float o)
 		int i, n = mSameOpacity ? mActors.Size() : l+1;
 		for(i=l; i<n; i++)
 		{
-			mActors[i]->GetProperty()->SetOpacity(o);
+			mActors[i]->GetProperty()->SetOpacity((o < mMaxOpacity) ? o : mMaxOpacity);
 			mOpacities[i] = o;
 		}
 		this->ClearCache();
