@@ -73,7 +73,7 @@ public:
 
 protected:
 	
-	iSolidViewSubject(iViewModule *vm, const iDataType &type, const iString &name, int numActors, unsigned int flags);
+	iSolidViewSubject(iViewModule *vm, const iDataType &type, const iString &name, int numActors, unsigned int flags, float maxOpacity = 1.0f);
 	virtual ~iSolidViewSubject();
 
 	virtual void ResetPipeline() = 0;
@@ -95,6 +95,7 @@ private:
 
 	const bool mNoColor, mNoOpacity, mNoPalette;
 	const bool mSameColor, mSameOpacity, mSamePalette;
+	const float mMaxOpacity;
 
 	virtual void ViewSubjectPackStateBody(iString &s) const;
 	virtual void ViewSubjectUnPackStateBody(const iString &s);
