@@ -28,6 +28,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "istring.h"
 
+
 #include "ierror.h"
 
 #include <math.h>
@@ -77,7 +78,7 @@ public:
 		memcpy(arr->mData,mData,mLen);
 	}
 
-	inline char* GetPointer(int i) const { return mData+i; }
+	inline char* GetPointer(int i) const { if(i>=0 && i<mLen) return mData+i; else return 0; }
 	inline int GetSize() const { return mLen; }
 	inline int GetReferenceCount() const { return mRef; }
 
@@ -114,7 +115,7 @@ iString::iString(const char *s, int l)
 
 	if(s != 0) 
 	{
-		mLen = strlen(s); 
+		mLen = int(strlen(s)); 
 		if(l>=0 && l<mLen) mLen = l;
 		mArr->SetSize(ARRSIZE(mLen));
 		memcpy(mArr->GetPointer(0),(const char *)s,mLen+1); 
@@ -257,7 +258,7 @@ iString& iString::operator+=(const iString &str)
 
 char iString::operator[](int i) const
 {
-	if(i < 0) return *(mArr->GetPointer(mLen+i)); else return *(mArr->GetPointer(i));
+	if(i>=0 && i<mLen) return *(mArr->GetPointer(i)); else return char(0);
 }
 
 
@@ -293,9 +294,19 @@ bool iString::IsEmpty() const
 }
 
 
+bool iString::IsAt(const iString &str, int index) const
+{
+	if(index>=0 && index<=mLen-str.mLen)
+	{
+		return (this->Find(str,index) == index);
+	}
+	else return false;
+}
+
+
 bool iString::EndsWith(const iString &str) const
 {
-	return strcmp(mArr->GetPointer(mLen-str.mLen),str.mArr->GetPointer(0)) == 0;
+	return (mLen>=str.mLen) && (strcmp(mArr->GetPointer(mLen-str.mLen),str.mArr->GetPointer(0))==0);
 }
 
 
@@ -341,22 +352,117 @@ int iString::Contains(const char *s, int index) const
 
 int iString::Find(char c, int index) const
 {
-	char *tmp;
 	if(index < 0) index += mLen;
 	if(index < 0) index = 0;
-	tmp = strchr(mArr->GetPointer(index),c);
-	if(tmp != 0) return tmp - mArr->GetPointer(0); else return -1;
+	char *tmp = strchr(mArr->GetPointer(index),c);
+	if(tmp != 0) return int(tmp-mArr->GetPointer(0)); else return -1;
 }
 
 
 int iString::Find(const char *s, int index) const
 {
+	if(s==0 || s[0]==0 || index>=mLen) return -1;
+
 	char *tmp;
-	if(s==0 || s[0]==0) return -1;
 	if(index < 0) index += mLen;
 	if(index < 0) index = 0;
 	tmp = strstr(mArr->GetPointer(index),s);
-	if(tmp != 0) return tmp - mArr->GetPointer(0); else return -1;
+	if(tmp != 0) return int(tmp-mArr->GetPointer(0)); else return -1;
+}
+
+
+int iString::FindIgnoringWhiteSpace(const iString &str, int index, int *last) const
+{
+	if(str.IsEmpty() || index>=mLen) return -1;
+
+	if(index < 0) index += mLen;
+	if(index < 0) index = 0;
+
+	int i, j, jstart = 0, len = str.Length();
+	while(this->IsWhiteSpace(index)) index++;
+	while(str.IsWhiteSpace(jstart)) jstart++;
+	if(index==mLen || jstart==len) return -1; // if any one is just whitespace, return -1
+
+	char *ptr = mArr->GetPointer(0);
+	i = index;
+	j = jstart;
+	while(i < mLen)
+	{
+		if(ptr[i] == str[j])
+		{
+			//
+			//  Partial match, advance indices
+			//
+			i++; j++;
+			while(this->IsWhiteSpace(i)) i++;
+			while(str.IsWhiteSpace(j)) j++;
+			if(j == len)
+			{
+				//
+				//  Hooray, we are done!
+				//
+				if(last != 0) *last = i;
+				return index;
+			}
+		}
+		else
+		{
+			//
+			//  Mismatch, reset i and j
+			//
+			index = i + (j > jstart ? 0 : 1);
+			while(this->IsWhiteSpace(index)) index++;
+			i = index;
+			j = jstart;
+		}
+	}
+	//
+	//  We did not find a match
+	//
+	return -1;
+}
+
+
+int iString::FindFromSet(const char *set, int index, int *length) const
+{
+	if(set==0 || set[0]==0 || index>=mLen) return -1;
+
+	if(index < 0) index += mLen;
+	if(index < 0) index = 0;
+	char *tmp = mArr->GetPointer(0);
+	int len;
+	while(index<mLen && (len=int(strspn(tmp+index,set)))==0) index++;
+	if(index < mLen)
+	{
+		if(length != 0) *length = len;
+		return index;
+	}
+	else return -1;
+}
+
+
+void iString::Replace(int index, char c)
+{
+	if(index < 0) index += mLen;
+	if(index>=0 && index<mLen)
+	{
+		if(mArr->GetReferenceCount() > 1)
+		{
+			//
+			//  Need to re-allocate
+			//
+			iCharArray *tmp;
+			tmp = iCharArray::New(); IERROR_ASSERT(tmp);
+			tmp->SetSize(ARRSIZE(mLen));
+			memcpy(tmp->GetPointer(0),mArr->GetPointer(0),mLen+1);
+			mArr->UnRegister();
+			mArr = tmp;
+#ifdef I_DEBUG
+			ptr = mArr->GetPointer(0);
+#endif
+		}
+		*(mArr->GetPointer(index)) = c;
+	}
 }
 
 
@@ -415,7 +521,7 @@ iString iString::Section(const iString &str, int start, int end) const
 		if(nsym < 0) nsym = 1 + this->Contains(str);
 		end += nsym;
 	}
-	if(start<0 || end<start) return iString();
+	if(start<0 || end<start || str.mLen==0) return iString();
 	//
 	//  Find starting section
 	//
@@ -424,7 +530,7 @@ iString iString::Section(const iString &str, int start, int end) const
 	{
 		s = strstr(p0+ioff1,p1);
 		if(s == 0) return iString();
-		ioff1 = s - p0 + str.mLen;
+		ioff1 = int(s-p0+str.mLen);
 	}
 	ioff2 = ioff1;
 	//
@@ -433,7 +539,7 @@ iString iString::Section(const iString &str, int start, int end) const
 	for(i=0; i<=end-start && s!=0; i++)
 	{
 		s = strstr(p0+ioff2,p1);
-		if(s != 0) ioff2 = s - p0 + str.mLen; else ioff2 = mLen + str.mLen;
+		if(s != 0) ioff2 = int(s-p0+str.mLen); else ioff2 = int(mLen+str.mLen);
 	}
 	//
 	//  Cut out the string
@@ -518,7 +624,7 @@ iString iString::FromNumber(void *d)
 {
 	const unsigned int n = 99;
 	char s[n];
-	sprintf(s,"%lX",(long)d);
+	sprintf(s,"%p",d);
 #ifdef I_CHECK1
 	if(strlen(s) > n)
 	{
@@ -529,6 +635,12 @@ iString iString::FromNumber(void *d)
 }
 
 
+iString iString::FromNumber(bool n)
+{
+	return (n ? "true" : "false");
+}
+
+
 int iString::ToInt(bool &ok) const
 {
 	int d; char c;
@@ -555,9 +667,9 @@ double iString::ToDouble(bool &ok) const
 
 void* iString::ToPointer(bool &ok) const
 {
-	long d; char c;
-	ok = (sscanf(mArr->GetPointer(0),"%lX%c",&d,&c) == 1);
-	return (void *)d;
+	void *d; char c;
+	ok = (sscanf(mArr->GetPointer(0),"%p%c",&d,&c) == 1);
+	return d;
 }
 
 
@@ -663,21 +775,15 @@ void iString::ReduceWhiteSpace()
 }
 
 
-void iString::RemoveFormatting(const iString &tokBeg, const iString &tokEnd)
+void iString::RemoveWhiteSpace()
 {
 	//
-	//  Remove all pieces of the string enclosed into tokBeg - tokEnd substrings
+	//  Remove all whitespace characters (codes 9-13 and 32).
 	//  This function works in place, without re-allocating memory, for un-shared strings. Must be 
 	//  better for cache coherence too. This is only possible because we only throw out characters, not add.
 	//
 	iCharArray *tmp = 0;
 	char *pd, *ps = mArr->GetPointer(0);
-	char *p;
-	int is, id;
-
-	const char *tb = tokBeg.ToCharPointer();
-	const char *te = tokEnd.ToCharPointer();
-	int le = tokEnd.Length();
 
 	if(mArr->GetReferenceCount() > 1)
 	{
@@ -693,44 +799,18 @@ void iString::RemoveFormatting(const iString &tokBeg, const iString &tokEnd)
 		pd = mArr->GetPointer(0);
 	}
 
-	is = id = 0;
-	while((p=strstr(ps+is,tb)) != 0)
+	int is, id;
+	for(is=id=0; is<mLen; is++)
 	{
-		//
-		//  Copy data before the opening token
-		//
-		if(ps+is != pd+id)
+		if(ps[is]!=32 && (ps[is]<9 || ps[is]>13)) 
 		{
-			while(ps+is != p) pd[id++] = ps[is++];
-		}
-		else
-		{
-			id = is = p - ps;
-		}
-		//
-		//  Find the closing token and skip the source data until it
-		//
-		if((p=strstr(ps+is,te)) != 0)
-		{
-			is = p - ps + le;
-		}
-		else
-		{
-			is = mLen;
+			//
+			//  not a whitespace
+			//
+			pd[id++] = ps[is];
 		}
 	}
-	//
-	//  Copy data after the last closing token
-	//
-	if(ps+is != pd+id)
-	{
-		while(ps[is] != 0) pd[id++] = ps[is++];
-		pd[id] = 0;
-	}
-	else
-	{
-		is = id = mLen;
-	}
+	pd[id] = 0;
 
 	mLen = id;
 
@@ -745,6 +825,63 @@ void iString::RemoveFormatting(const iString &tokBeg, const iString &tokEnd)
 }
 
 
+void iString::FindTokenMatch(const iString &tokBeg, int &indBeg, const iString &tokEnd, int &indEnd, int index, bool multiLevel) const
+{
+	//
+	//  Find the first match
+	//
+	indBeg = this->Find(tokBeg,index);
+	if(indBeg < 0)
+	{
+		indEnd = -1;
+		return;
+	}
+
+	if(multiLevel)
+	{
+		//
+		//  Count opening and closing tokens until we get a match
+		//
+		int i1, i2, fin, stack = 1;
+		i1 = this->Find(tokBeg,indBeg+1);
+		fin = i2 = this->Find(tokEnd,indBeg+1);
+		while(i2!=-1 && stack>0)
+		{
+			if(i1!=-1 && i1<i2)
+			{
+				stack++;
+				i1 = this->Find(tokBeg,i1+1);
+			} 
+			else
+			{
+				stack--;
+				fin = i2;
+				i2 = this->Find(tokEnd,i2+1);
+			}
+		}
+
+		if(stack == 0) indEnd = fin; else indEnd = -1;
+	}
+	else
+	{
+		indEnd = this->Find(tokEnd,indBeg+1);
+	}
+}
+
+
+void iString::RemoveFormatting(const iString &tokBeg, const iString &tokEnd, bool multiLevel)
+{
+	int iBeg, iEnd;
+	do
+	{
+        this->FindTokenMatch(tokBeg,iBeg,tokEnd,iEnd,0,multiLevel);
+		if(iEnd < 0) iEnd = mLen - 1; else iEnd += tokEnd.Length() - 1;
+		if(iBeg > -1) this->Replace(iBeg,iEnd-iBeg+1,"");
+	}
+	while(iBeg != -1);
+}
+
+
 void iString::ReformatHTMLToText(int length)
 {
 	int i;
