@@ -29,6 +29,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "isurfaceviewsubject.h"
 
 
+#include "iartifactcorrector.h"
 #include "icommondatadistributors.h"
 #include "icolorbars.h"
 #include "idatahelper.h"
@@ -47,6 +48,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkMassProperties.h>
 #include <vtkPolyData.h>
 #include <vtkPolyDataConnectivityFilter.h>
+#include <vtkProperty.h>
 #include <vtkTriangleFilter.h>
 
 //
@@ -90,6 +92,43 @@ IOBJECT_DEFINE_KEY(iSurfaceViewSubject,ProbePositionToPickedPoint,-p2p,Bool,1);
 #endif
 
 
+namespace iSurfaceViewSubject_Private
+{
+	//
+	//  Correct antialising artifact for opaque particles
+	//
+	class ArtifactCorrector : public iArtifactCorrector
+	{
+
+		IGENERICFILTER_DECLARE(ArtifactCorrector,iArtifactCorrector);
+
+	protected:
+
+		virtual bool HasArtifacts(vtkRenderer *ren, vtkProperty *prop)
+		{
+			vtkPolyData *output = this->GetOutput();
+
+			//
+			//  Activate for mildly transparent surfaces
+			//
+			if((output->GetNumberOfPolys()>0 || output->GetNumberOfStrips()>0) && prop!=0)
+			{
+				return (prop->GetOpacity()>0.2 && prop->GetOpacity()<1.0);
+			}
+			else return false;
+		}
+	};
+
+
+	ArtifactCorrector::ArtifactCorrector(iViewSubject *vo) : iArtifactCorrector(vo)
+	{
+	}
+}
+
+
+using namespace iSurfaceViewSubject_Private;
+
+
 //
 // iSurfaceViewSubject class
 //
@@ -99,7 +138,7 @@ iSurfaceViewSubject::iSurfaceViewSubject(iViewModule *vm, const iDataType &type,
 
 	mLev = 0.0f;
 	mVar = 0;
-#if defined(IVTK_4) && defined(VTK_USE_PATENTED)
+#if defined(IVTK_44) && defined(VTK_USE_PATENTED)
 	//
 	//  vtkMarchingContourFilter has an obscure bug undet VTK 5 and in multi-threaded mode.
 	//
@@ -151,6 +190,13 @@ iSurfaceViewSubject::iSurfaceViewSubject(iViewModule *vm, const iDataType &type,
 	mAttachedMarkerIndex = -1;
 	mAttachedMarker = 0;
 
+	ArtifactCorrector *ac = ArtifactCorrector::New(this); IERROR_ASSERT(ac);
+	mActors[0]->InstallArtifactCorrector(ac);
+	ac->Delete();
+	ac = ArtifactCorrector::New(this); IERROR_ASSERT(ac);
+	mActors[1]->InstallArtifactCorrector(ac);
+	ac->Delete();
+
 	//
 	//  Add observer to keep information about this object
 	//
