@@ -31,6 +31,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <vtkMath.h>
 
+#include "ivtk.h"
+
 
 iTransform* iTransform::New()
 {
@@ -71,7 +73,11 @@ void iTransform::SetDirection(const float *dir)
 	float d = vtkMath::Dot(base,dir)/vtkMath::Norm(dir);
 	if(vtkMath::Norm(axis) > 0.0)
 	{
+#ifdef IVTK_PRE54
 		this->RotateWXYZ(vtkMath::RadiansToDegrees()*acos(d),axis);
+#else
+		this->RotateWXYZ(vtkMath::DegreesFromRadians(acos(d)),axis);
+#endif
 	}
 	else
 	{
