@@ -494,12 +494,7 @@ void iVectorFieldViewSubject::SetNumberOfStreamLines(int v)
 
 void iVectorFieldViewSubject::SetSourceOpacity(float v)
 {
-	if(v>0.0f && !(v>1.0f))
-	{
-		mOpacities[1] = v;
-		mActors[1]->GetProperty()->SetOpacity(v);
-		this->ClearCache();
-	}
+	this->SetOpacity(1,v);
 }
 
 
