@@ -32,9 +32,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iactor.h"
 #include "iactorcollection.h"
 #include "ianimator.h"
+#include "iartifactcorrector.h"
 #include "icamera.h"
 #include "icameraorthoactor.h"
 #include "icaptioninteractorstyle.h"
+#include "icaption.h"
 #include "iclipplane.h"
 #include "icolorbars.h"
 #include "icommoneventobservers.h"
@@ -52,20 +54,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iimagecomposer.h"
 #include "iinteractoreventrecorder.h"
 #include "ikeyboardinteractorstyle.h"
-#include "ilegend.h"
 #include "ilightkit.h"
 #include "imarker.h"
 #include "imarkerfamily.h"
 #include "imath.h"
 #include "imeasuringbox.h"
-#include "imeasuringboxinteractorstyle.h"
 #include "iobjectfactory.h"
 #include "ioverlayhelper.h"
 #include "ipalette.h"
 #include "iparallelmanager.h"
 #include "iparticlesviewsubject.h"
 #include "ipicker.h"
-#include "ipointglyph.h"
 #include "iposition.h"
 #include "irendertool.h"
 #include "iruler.h"
@@ -99,7 +98,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkMatrix4x4.h>
 #include <vtkPicker.h>
 #include <vtkPointData.h>
-#include <vtkPointWidget.h>
 #include <vtkPolyData.h>
 #include <vtkPolyDataMapper2D.h>
 #include <vtkPropAssembly.h>
@@ -127,6 +125,7 @@ using namespace iParameter;
 IOBJECT_DEFINE_TYPE(iViewModule,ViewModule,vm,iObjectType::_Module);
 
 IOBJECT_DEFINE_KEY(iViewModule,Antialiasing,a,Bool,1);
+IOBJECT_DEFINE_KEY(iViewModule,ArtifactCorrection,ac,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,AxesBoxLabels,abl,String,3);
 IOBJECT_DEFINE_KEY(iViewModule,AxesBoxRanges,abr,Float,6);
 IOBJECT_DEFINE_KEY(iViewModule,AnimationOutput,ao,Int,1);
@@ -134,6 +133,7 @@ IOBJECT_DEFINE_KEY(iViewModule,BoundingBox,bb,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,BoundingBoxType,bbt,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,BackgroundColor,bg,Color,1);
 IOBJECT_DEFINE_KEY(iViewModule,BackgroundImage,bi,String,1);
+IOBJECT_DEFINE_KEY(iViewModule,BackgroundImageFixedAspect,bia,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,BoxSize,bs,Float,1);
 IOBJECT_DEFINE_KEY(iViewModule,CameraAlignmentLabel,ca,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,ColorBars,cb,Bool,1);
@@ -158,6 +158,8 @@ IOBJECT_DEFINE_KEY(iViewModule,LabelOffset,lo,Float,1);
 IOBJECT_DEFINE_KEY(iViewModule,LabelScale,ls,Float,1);
 IOBJECT_DEFINE_KEY(iViewModule,LabelUnit,lu,String,1);
 IOBJECT_DEFINE_KEY(iViewModule,MeasuringBox,mb,Bool,1);
+IOBJECT_DEFINE_KEY(iViewModule,MarkerCaptionsTransparent,mct,Bool,1);
+IOBJECT_DEFINE_KEY(iViewModule,MarkerHandles,mh,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,MarkerLegend,ml,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,MarkerLegendPosition,mlp,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,MoveMarkerCaption,mmc,Bool,1);
@@ -170,7 +172,6 @@ IOBJECT_DEFINE_KEY(iViewModule,SurfaceCurrent,osc,OffsetInt,1);
 IOBJECT_DEFINE_KEY(iViewModule,SurfaceMax,osm,OffsetInt,1);
 IOBJECT_DEFINE_KEY(iViewModule,CrossSectionCurrent,oxc,OffsetInt,1);
 IOBJECT_DEFINE_KEY(iViewModule,CrossSectionMax,oxm,OffsetInt,1);
-IOBJECT_DEFINE_KEY(iViewModule,PlaceMarker,pm,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,Position,p,Int,2);
 IOBJECT_DEFINE_KEY(iViewModule,PostScriptPaperFormat,psf,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,PostScriptOrientation,pso,Int,1);
@@ -179,7 +180,7 @@ IOBJECT_DEFINE_KEY(iViewModule,RulerScale,rs,Float,1);
 IOBJECT_DEFINE_KEY(iViewModule,RulerTitle,rt,String,1);
 IOBJECT_DEFINE_KEY(iViewModule,Size,s,Int,2);
 IOBJECT_DEFINE_KEY(iViewModule,UpdateRate,r,Int,1);
-IOBJECT_DEFINE_KEY(iViewModule,StereoAlignmentMarkers,sam,Bool,1);
+IOBJECT_DEFINE_KEY(iViewModule,StereoAlignmentMarks,sam,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,Stereo,ss,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,StereoType,st,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,WindowNumber,wn,Int,1);
@@ -242,15 +243,16 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 {
 	int i;
 	
-	mFontScale = 0;
-	mFontType = _TextTypeBitmapArial;
 	mBoxType = -1; // needs to be reset
 	mImageMagnification = 1;
 	mSavedProjection = 0;
 
+	mArtifactCorrection = iArtifactCorrector::IsEnabled();
+
 	mIsDebug = false;
 	mAntialiasing = true;
 	mInImageRender = false;
+	mBackgroundImageFixedAspect = false;
 
 	mRate = 0;
 	mBoxSize = -1.0;
@@ -265,7 +267,7 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	mIsRulerOn = false;
 	mIsClipPlaneOn = false;
 	mIsGlassClipPlaneOn = false;
-	mIsStereoAlignmentMarkersOn = true;
+	mIsStereoAlignmentMarksOn = true;
 
 	mLabelJustificationLeft = false;
 	mStereoType = VTK_STEREO_RED_BLUE;
@@ -288,13 +290,13 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	//
 	//  Attach to Interactor Observer
 	//
-	mRenderTool->GetInteractor()->AddObserver(vtkCommand::LeftButtonPressEvent,this->GetControlModule()->GetInteractorObserver());
-	mRenderTool->GetInteractor()->AddObserver(vtkCommand::LeftButtonReleaseEvent,this->GetControlModule()->GetInteractorObserver());
+	mRenderTool->GetInteractor()->AddObserver(vtkCommand::LeftButtonPressEvent,this->GetControlModule()->GetInteractorObserver(),-1.0);
+	mRenderTool->GetInteractor()->AddObserver(vtkCommand::LeftButtonReleaseEvent,this->GetControlModule()->GetInteractorObserver(),-1.0);
 	mRenderTool->GetInteractor()->AddObserver(vtkCommand::MiddleButtonPressEvent,this->GetControlModule()->GetInteractorObserver());
 	mRenderTool->GetInteractor()->AddObserver(vtkCommand::MiddleButtonReleaseEvent,this->GetControlModule()->GetInteractorObserver());
 	mRenderTool->GetInteractor()->AddObserver(vtkCommand::RightButtonPressEvent,this->GetControlModule()->GetInteractorObserver());
 	mRenderTool->GetInteractor()->AddObserver(vtkCommand::RightButtonReleaseEvent,this->GetControlModule()->GetInteractorObserver());
-	mRenderTool->GetInteractor()->AddObserver(vtkCommand::MouseMoveEvent,this->GetControlModule()->GetInteractorObserver());
+	mRenderTool->GetInteractor()->AddObserver(vtkCommand::MouseMoveEvent,this->GetControlModule()->GetInteractorObserver(),-1.0);
 
 	//
 	//  File reader, gateway, volume converter
@@ -346,9 +348,7 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	//
 	mLabelActor = iTextActor::New(mRenderTool); IERROR_ASSERT(mLabelActor);
 	mLabelActor->SetText("");
-	mLabelActor->SetBold(true);
-	mLabelActor->SetHJustification(_TextJustRight);
-	mLabelActor->SetVJustification(_TextJustTop);
+	mLabelActor->SetJustification(1,1);
 	mLabelActor->SetPosition(0.95,0.9);
 	mLabelActor->VisibilityOff();
 	mLabelActor->PickableOff();
@@ -362,9 +362,6 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	mMeasuringBox->VisibilityOff();
 	mRenderTool->AddObject(mMeasuringBox);
 
-	mInteractorStyleMeasuringBox = iMeasuringBoxInteractorStyle::New(); IERROR_ASSERT(mInteractorStyleMeasuringBox);
-	mInteractorStyleMeasuringBox->SetMeasuringBox(mMeasuringBox);
-
 	//
 	//  Color bars
 	//
@@ -402,19 +399,15 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	mInteractorStyle[_InteractorStyleKeyboard] = iKeyboardInteractorStyle::New();
 //	mInteractorStyle[_InteractorStyleKeyboard] = vtkInteractorStyleUnicam::New();
 
-	for(i=0; i<__NumInteractorStyles; i++) IERROR_ASSERT(mInteractorStyle[i]);
+	for(i=0; i<__NumInteractorStyles; i++)
+	{
+		IERROR_ASSERT(mInteractorStyle[i]);
+		mMeasuringBox->AttachToInteractorStyle(mInteractorStyle[i]);
+	}
 
 	isf->SetAngleStepSize(0.1);
 	isf->SetMotionStepSize(0.001);
 
-	//
-	//  Work around for a VTK bug: undefined angles in vtkInteractorStyleFlight.
-	//
-	{
-		mRenderTool->GetInteractor()->SetInteractorStyle(isf);
-		isf->ForwardFly();
-	}
-
 	mRenderTool->GetInteractor()->SetInteractorStyle(mInteractorStyle[mCurrentInteractorStyle]);
 
 	//
@@ -434,11 +427,8 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	mRenderTool->GetInteractor()->SetPicker(mPicker->GetHandler());
 
 	//
-	//  Event recorder & marker helpers
+	//  Event recorder
 	//  
-	mIsMarkerLegendOn = false;
-	mMarkerLegendPosition = 0;
-
 	mEventRecorder = iInteractorEventRecorder::New(); IERROR_ASSERT(mEventRecorder);
 	mEventRecorder->SetInteractor(mRenderTool->GetInteractor());
 	mEventRecorder->SetEnabled(1);
@@ -447,34 +437,9 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 
 	for(i=0; i<__NumInteractorStyles; i++) mInteractorStyle[i]->AddObserver(vtkCommand::InteractionEvent,mObsRecord);
 
-	mMarkerPlacer = vtkPointWidget::New(); IERROR_ASSERT(mMarkerPlacer);
-	mMarkerPlacer->XShadowsOn();
-	mMarkerPlacer->YShadowsOn();
-	mMarkerPlacer->ZShadowsOn();
-	mMarkerPlacer->OutlineOff();
-	mMarkerPlacer->TranslationModeOff();
-	mMarkerPlacer->SetInteractor(mRenderTool->GetInteractor());
-	mMarkerPlacer->GetProperty()->SetColor(0.0,0.0,0.0);
-	mMarkerPlacer->GetProperty()->SetLineWidth(4.0);
-//	mMarkerPlacer->GetSelectedProperty()->SetColor(1.0,0.0,0.0);
-	mMarkerPlacer->GetSelectedProperty()->SetLineWidth(2.0);
-	mMarkerPlacer->PlaceWidget(-1.0,1.0,-1.0,1.0,-1.0,1.0);
-
-	mObsMarker = iMarkerEventObserver::New(this); IERROR_ASSERT(mObsMarker);
-
-	mMarkerPlacer->AddObserver(vtkCommand::InteractionEvent,mObsMarker);
-	mMarkerPlacer->AddObserver(vtkCommand::EndInteractionEvent,mObsMarker);
-
 	//
-	//  vtkLegendBoxActor is defined under earlier VTK versions, but
-	//  markers cannot be positioned without the vtkPointWidgets, so the legend
-	//  is useless then too.
+	//  Must be created before marker family
 	//
-	mMarkerLegend = iLegend::New(mRenderTool); IERROR_ASSERT(mMarkerLegend);
-	this->SetMarkerLegendPosition(mMarkerLegendPosition);
-	mRenderTool->AddObject(mMarkerLegend);
-	mMarkerLegend->VisibilityOff();
-
 	mInteractorStyleCaption = iCaptionInteractorStyle::New(this); IERROR_ASSERT(mInteractorStyleCaption);
 
 	//
@@ -513,8 +478,6 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	//
 	//  Set the font size
 	//
-	this->SetFontScale(mFontScale);
-	this->SetFontType(mFontType);
 	this->SetAntialiasing(mAntialiasing);
 	this->SetBackgroundColor(mBackgroundColor);
 
@@ -559,11 +522,6 @@ iViewModule::~iViewModule()
 	mPicker->Delete();
 
 	for(i=0; i<mViewObjectFamilies.Size(); i++) mViewObjectFamilies[i]->Delete();
-	//
-	//  Legend needs to be deleted before markers - otherwise, markers get stuck somewhere and GarbareCollector crashes.
-	//
-	mRenderTool->RemoveObject(mMarkerLegend);
-	mMarkerLegend->Delete();
 	mMarkerFamily->Delete();
 	
 	mRenderTool->RemoveObject(mBox3AxesLabels);
@@ -583,9 +541,6 @@ iViewModule::~iViewModule()
 	mEventRecorder->SetInteractor(0);
 	mEventRecorder->Delete();
 	mObsRecord->Delete();
-	mMarkerPlacer->Off();
-	mMarkerPlacer->SetInteractor(0);
-	mMarkerPlacer->Delete();
 	mInteractorStyleCaption->Delete();
 
 	mUpdateTimer->Delete();
@@ -599,8 +554,6 @@ iViewModule::~iViewModule()
 	mBox3Actor->Delete();
 	mDebugActor->Delete();
 
-	mInteractorStyleMeasuringBox->Delete();
-
 	mRenderTool->RemoveObject(mIconActor);
 	mIconActor->Delete();
 
@@ -898,30 +851,6 @@ void iViewModule::SetAxesBox(const iString &labelX, const iString &labelY, const
 }
 
 
-void iViewModule::SetFontScale(int s)
-{
-	if(s>-10 && s<10)
-	{
-		mFontScale = s; 
-		this->ClearCache();
-	}
-}
-
-
-void iViewModule::SetFontType(int s)
-{
-	mLabelActor->SetFontType(s); 
-	if(s == mLabelActor->GetFontType())
-	{
-		mFontType = s; 
-//		mRulerActor->SetFontType(s);
-		mMeasuringBox->GetTextActor()->SetFontType(s);
-		mColorBars->SetFontType(s);
-		this->ClearCache();
-	}
-}
-
-
 void iViewModule::ShowBoundingBox(bool s)
 {
 	this->ClearCache();
@@ -987,12 +916,10 @@ void iViewModule::ShowMeasuringBox(bool s)
 	if(s)
 	{
 		mMeasuringBox->VisibilityOn(); 
-		mRenderTool->GetInteractor()->SetInteractorStyle(mInteractorStyleMeasuringBox);
 	} 
 	else 
 	{
 		mMeasuringBox->VisibilityOff();
-		mRenderTool->GetInteractor()->SetInteractorStyle(mInteractorStyle[mCurrentInteractorStyle]);
 	}
 	mIsMeasuringBoxOn = s;
 	this->ClearCache();
@@ -1026,10 +953,10 @@ void iViewModule::ShowCameraAlignmentLabel(bool s)
 }
 
 
-void iViewModule::ShowStereoAlignmentMarkers(bool s)
+void iViewModule::ShowStereoAlignmentMarks(bool s)
 {
-	mIsStereoAlignmentMarkersOn = s;
-	mRenderTool->ShowStereoAlignmentMarkers(s);
+	mIsStereoAlignmentMarksOn = s;
+	mRenderTool->ShowStereoAlignmentMarks(s);
 	this->ClearCache();
 }
 
@@ -1059,6 +986,7 @@ void iViewModule::ShowLabel(bool s, float *pv)
 			if(fabs(mLabelScale) > 0.0) v = mLabelScale*(r-mLabelOffset); else
 			{
 				unit.Clear();
+				if(mDataReader->GetFileSetRoot().EndsWith("1.")) r += 10000;
 				v = 1.0e4/((r>0)?r:1)-1.0;
 			}
 		}
@@ -1120,31 +1048,11 @@ void iViewModule::ShowLabel(bool s, float *pv)
 
 void iViewModule::JustifyLabelLeft(bool s)
 {
-	if(s)
+	if(s != mLabelJustificationLeft)
 	{
-		if(!mLabelJustificationLeft)
-		{
-			mLabelJustificationLeft = true;
-			float s[2];
-			const float *p;
-			mLabelActor->GetSize(s);
-			mLabelActor->SetHJustification(_TextJustLeft);
-			p = mLabelActor->GetPosition();
-			mLabelActor->SetPosition(p[0]-s[0],p[1]);
-		}
-	}
-	else
-	{
-		if(mLabelJustificationLeft)
-		{
-			mLabelJustificationLeft = false;
-			float s[2];
-			const float *p;
-			mLabelActor->GetSize(s);
-			mLabelActor->SetHJustification(_TextJustRight);
-			p = mLabelActor->GetPosition();
-			mLabelActor->SetPosition(p[0]+s[0],p[1]);
-		}
+		mLabelJustificationLeft = s;
+		mLabelActor->MoveJustification(s?-1:1);
+		this->ClearCache();
 	}
 }
 
@@ -1170,6 +1078,7 @@ void iViewModule::SetInteractorStyle(int n)
 		{
 			mSavedProjection = mRenderTool->GetCamera()->GetDevice()->GetParallelProjection();
 			mRenderTool->GetCamera()->GetDevice()->ParallelProjectionOff();
+			//mRenderTool->GetInteractor()->SetLastEventPosition(mRenderTool->GetInteractor()->GetEventPosition());
 		} 
 		else if(mCurrentInteractorStyle == _InteractorStyleFlight)
 		{
@@ -1192,7 +1101,7 @@ void iViewModule::SetBackgroundColor(const iColor &bg)
 	mMeasuringBox->SetColor(fg);
 	mBox1Actor->GetProperty()->SetColor(fg.ToVTK());
 	mAnimator->SetCameraPathColor(fg);
-	mMarkerPlacer->GetProperty()->SetColor(fg.ToVTK());
+	mMarkerFamily->SetHandlesColor(fg);
 	this->ClearCache();
 }
 
@@ -1216,6 +1125,17 @@ void iViewModule::SetBackgroundImage(const iString &name)
 }
 
 
+void iViewModule::SetBackgroundImageFixedAspect(bool s)
+{
+	if(mBackgroundImageFixedAspect != s)
+	{
+		mRenderTool->SetBackgroundImageFixedAspect(s);
+		mBackgroundImageFixedAspect = s;
+		this->ClearCache();
+	}
+}
+
+
 void iViewModule::SetBoundingBoxType(int s)
 {
 	if(s!=mBoxType && s>=0 && s<__NumBoundingBoxTypes)
@@ -1235,6 +1155,15 @@ void iViewModule::SetAntialiasing(bool s)
 }
 
 
+void iViewModule::SetArtifactCorrection(bool s)
+{
+	mArtifactCorrection = s;
+	iArtifactCorrector::Enable(s);
+	this->GetRenderer()->GetActiveCamera()->Modified();
+	this->ClearCache();
+}
+
+
 void iViewModule::UpdateIcon()
 {
 	int i;
@@ -1452,9 +1381,11 @@ void iViewModule::ExtendableObjectPackStateBody(iString &s) const
 	this->PackValue(s,KeyMeasuringBox(),mIsMeasuringBoxOn);
 	this->PackValue(s,KeyAntialiasing(),mAntialiasing);
 	this->PackValue(s,KeyJustifyLabelLeft(),mLabelJustificationLeft);
-	this->PackValue(s,KeyMarkerLegend(),mIsMarkerLegendOn);
+	this->PackValue(s,KeyMarkerLegend(),mMarkerFamily->IsLegendVisible());
 	this->PackValue(s,KeyStereo(),this->GetStereo());
-	this->PackValue(s,KeyStereoAlignmentMarkers(),mIsStereoAlignmentMarkersOn);
+	this->PackValue(s,KeyStereoAlignmentMarks(),mIsStereoAlignmentMarksOn);
+	this->PackValue(s,KeyArtifactCorrection(),mArtifactCorrection);
+	this->PackValue(s,KeyBackgroundImageFixedAspect(),mBackgroundImageFixedAspect);
 
 	this->PackValue(s,KeyLabelName(),mLabelName);
 	this->PackValue(s,KeyLabelUnit(),mLabelUnit);
@@ -1462,14 +1393,16 @@ void iViewModule::ExtendableObjectPackStateBody(iString &s) const
 	this->PackValue(s,KeyLabelOffset(),mLabelOffset);
 	this->PackValue(s,KeyLabelDigits(),mLabelDigits);
 
-	this->PackValue(s,KeyFontScale(),mFontScale);
-	this->PackValue(s,KeyFontType(),mFontType);
+	this->PackValue(s,KeyFontScale(),this->GetFontScale());
+	this->PackValue(s,KeyFontType(),this->GetFontType());
 	this->PackValue(s,KeyBoundingBoxType(),mBoxType);
 	this->PackValue(s,KeyImageFormat(),mWriter->GetImageFormat());
 	this->PackValue(s,KeyAnimationOutput(),mWriter->GetAnimationOutput());
-	this->PackValue(s,KeyMarkerLegendPosition(),mMarkerLegendPosition);
+	this->PackValue(s,KeyMarkerLegendPosition(),mMarkerFamily->GetLegendPosition());
 	this->PackValue(s,KeyImageMagnification(),mImageMagnification);
 	this->PackValue(s,KeyStereoType(),this->GetStereoType());
+	this->PackValue(s,KeyMarkerHandles(),mMarkerFamily->IsHandlesVisible());
+	this->PackValue(s,KeyMarkerCaptionsTransparent(),iCaption::Transparent);
 
 	this->PackValue(s,KeyBackgroundColor(),mBackgroundColor);
 	this->PackValue(s,KeyBackgroundImage(),mBackgroundImage);
@@ -1515,9 +1448,6 @@ void iViewModule::ExtendableObjectPackStateBody(iString &s) const
 	this->PackValue(s,KeyParticlesMax(),this->GetParticlesObject()->GetNumberOfTypes()-1);
 	this->PackValue(s,KeySurfaceMax(),mViewObjectFamilies[_ObjectTypeSurface]->GetMaxMemberIndex());
 	this->PackValue(s,KeyCrossSectionMax(),mViewObjectFamilies[_ObjectTypeCrossSection]->GetMaxMemberIndex());
-
-	this->PackValue(s,KeyPlaceMarker(),mMarkerPlacer->GetEnabled()!=0);
-	this->PackValue(s,KeyMoveMarkerCaption(),mRenderTool->GetInteractor()->GetInteractorStyle()==mInteractorStyleCaption);
 }
 
 
@@ -1556,9 +1486,11 @@ void iViewModule::ExtendableObjectUnPackStateBody(const iString &s)
 	if(this->UnPackValue(s,KeyMeasuringBox(),b)) this->ShowMeasuringBox(b);
 	if(this->UnPackValue(s,KeyAntialiasing(),b)) this->SetAntialiasing(b);
 //	if(this->UnPackValue(s,KeyJustifyLabelLeft(),b)) this->justifyLabelLeft(b);
-	if(this->UnPackValue(s,KeyMarkerLegend(),b)) this->ShowMarkerLegend(b);
+	if(this->UnPackValue(s,KeyMarkerLegend(),b)) mMarkerFamily->ShowLegend(b);
 	if(this->UnPackValue(s,KeyStereo(),b)) this->SetStereo(b);
-	if(this->UnPackValue(s,KeyStereoAlignmentMarkers(),b)) this->ShowStereoAlignmentMarkers(b);
+	if(this->UnPackValue(s,KeyStereoAlignmentMarks(),b)) this->ShowStereoAlignmentMarks(b);
+	if(this->UnPackValue(s,KeyArtifactCorrection(),b)) this->SetArtifactCorrection(b);
+	if(this->UnPackValue(s,KeyBackgroundImageFixedAspect(),b)) this->SetBackgroundImageFixedAspect(b);
 
 	iObject::ReportMissingKeys(false);
 	if(this->UnPackValue(s,KeyFontSize(),i)) this->SetFontScale(round(log(i/16.0)/0.3)); // for backward compatibility only
@@ -1569,10 +1501,12 @@ void iViewModule::ExtendableObjectUnPackStateBody(const iString &s)
 	if(this->UnPackValue(s,KeyBoundingBoxType(),i)) this->SetBoundingBoxType(i);
 	if(this->UnPackValue(s,KeyImageFormat(),i)) mWriter->SetImageFormat(i);
 	if(this->UnPackValue(s,KeyAnimationOutput(),i)) mWriter->SetAnimationOutput(i);
-	if(this->UnPackValue(s,KeyMarkerLegendPosition(),i)) this->SetMarkerLegendPosition(i);
+	if(this->UnPackValue(s,KeyMarkerLegendPosition(),i)) mMarkerFamily->SetLegendPosition(i);
 	if(this->UnPackValue(s,KeyImageMagnification(),i)) this->SetImageMagnification(i);
 	if(this->UnPackValue(s,KeyStereoType(),i)) this->SetStereoType(i);
-	
+	if(this->UnPackValue(s,KeyMarkerHandles(),b)) mMarkerFamily->ShowHandles(b);
+	if(this->UnPackValue(s,KeyMarkerCaptionsTransparent(),b)) iCaption::Transparent = b;
+
 	if(this->UnPackValue(s,KeyLabelName(),w)) this->SetLabelName(w);
 	if(this->UnPackValue(s,KeyLabelUnit(),w)) this->SetLabelUnit(w);
 	if(this->UnPackValue(s,KeyLabelScale(),f)) this->SetLabelScale(f);
@@ -1647,101 +1581,17 @@ void iViewModule::ExtendableObjectUnPackStateBody(const iString &s)
 	//
 	iObject::ReportMissingKeys(false); //action keys are not part of the states
 
-	if(this->UnPackValue(s,KeyPlaceMarker(),b)) this->PlaceMarker(b);
-	if(this->UnPackValue(s,KeyMoveMarkerCaption(),b)) this->MoveMarkerCaption(b);
+	if(this->UnPackValue(s,KeyMoveMarkerCaption(),b) && b)
+	{
+		this->GetRenderTool()->GetInteractor()->SetInteractorStyle(mInteractorStyleCaption);
+		mInteractorStyleCaption->Launch(mInteractorStyle[mCurrentInteractorStyle]);
+	}
 	if(this->UnPackValue(s,KeyDumpImage(),b) && b) this->DumpImages();
 
 	iObject::ReportMissingKeys(true);
 }
 
 
-void iViewModule::PlaceMarker(bool s)
-{
-	if(s)
-	{
-		mMarkerPlacer->SetPosition(mMarkerFamily->GetCurrentMember()->GetPosition()[0],mMarkerFamily->GetCurrentMember()->GetPosition()[1],mMarkerFamily->GetCurrentMember()->GetPosition()[2]);
-		mMarkerPlacer->On();
-	}
-	else
-	{
-		mMarkerPlacer->Off();
-	}
-}
-
-
-void iViewModule::MoveMarkerCaption(bool s)
-{
-	if(s)
-	{
-		mRenderTool->GetInteractor()->SetInteractorStyle(mInteractorStyleCaption);
-	}
-	else
-	{
-		mRenderTool->GetInteractor()->SetInteractorStyle(mInteractorStyle[mCurrentInteractorStyle]);
-	}
-}
-
-
-void iViewModule::ShowMarkerLegend(bool s)
-{
-	mIsMarkerLegendOn = s;
-	if(s) 
-	{
-		this->BuildMarkerLegend();
-		mMarkerLegend->VisibilityOn(); 
-	}
-	else mMarkerLegend->VisibilityOff();
-	this->ClearCache();
-}
-
-
-void iViewModule::BuildMarkerLegend(int n)
-{
-	int i;
-	if(n<0 || n>mMarkerFamily->GetMaxMemberIndex())
-	{
-		mMarkerLegend->SetNumberOfEntries(1+mMarkerFamily->GetMaxMemberIndex());
-		for(i=0; i<=mMarkerFamily->GetMaxMemberIndex(); i++)
-		{
-			//
-			//  Fix a bug in vtkLegendBoxActor
-			//
-			if(mMarkerFamily->GetMember(i)->GetCaptionText().Length() > 0) mMarkerLegend->SetEntry(i,mMarkerFamily->GetMember(i)->GetMarkerObject()->GetOutput(),mMarkerFamily->GetMember(i)->GetCaptionText().ToCharPointer(),mMarkerFamily->GetMember(i)->GetColor(0).ToVTK()); else mMarkerLegend->SetEntry(i,mMarkerFamily->GetMember(i)->GetMarkerObject()->GetOutput()," ",mMarkerFamily->GetMember(i)->GetColor(0).ToVTK());
-		}
-	}
-	else
-	{
-		//
-		//  Fix a bug in vtkLegendBoxActor
-		//
-		if(mMarkerFamily->GetMember(n)->GetCaptionText().Length() > 0) mMarkerLegend->SetEntry(n,mMarkerFamily->GetMember(n)->GetMarkerObject()->GetOutput(),mMarkerFamily->GetMember(n)->GetCaptionText().ToCharPointer(),mMarkerFamily->GetMember(n)->GetColor(0).ToVTK()); else mMarkerLegend->SetEntry(n,mMarkerFamily->GetMember(n)->GetMarkerObject()->GetOutput()," ",mMarkerFamily->GetMember(n)->GetColor(0).ToVTK());
-	}
-}
-
-
-void iViewModule::SetMarkerLegendPosition(int p)
-{
-	if(p>=0 && p<=1)
-	{
-		mMarkerLegendPosition = p;
-		switch (p)
-		{
-		case 0:
-			{
-				mMarkerLegend->SetPosition(0.73,0.02);
-				break;
-			}
-		case 1:
-			{
-				mMarkerLegend->SetPosition(0.02,0.02);
-				break;
-			}
-		}
-		this->ClearCache();
-	}
-}
-
-
 float iViewModule::GetMemorySize() const
 {
 	int i;
@@ -1918,6 +1768,32 @@ int iViewModule::GetStereoType() const
 }
 
 
+void iViewModule::SetFontScale(int s)
+{
+	mRenderTool->SetFontScale(s); 
+	this->ClearCache();
+}
+
+
+int iViewModule::GetFontScale() const
+{
+	return mRenderTool->GetFontScale();
+}
+
+
+void iViewModule::SetFontType(int s)
+{
+	mRenderTool->SetFontType(s); 
+	this->ClearCache();
+}
+
+
+int iViewModule::GetFontType() const
+{
+	return mRenderTool->GetFontType();
+}
+
+
 //
 //  Access to RenderTool components
 //
@@ -2394,7 +2270,7 @@ namespace iViewModule_Private
 
 		actor->SetMapper(mapper);
 		mapper->Delete();
-		actor->GetPositionCoordinate()->SetCoordinateSystemToNormalizedDisplay();
+		actor->GetPositionCoordinate()->SetCoordinateSystemToNormalizedViewport();
 		actor->SetPosition(0.05,0.95);
 		actor->GetProperty()->SetLineWidth(2.0);
 		actor->VisibilityOff();
