@@ -56,12 +56,9 @@ class iDataReader;
 class iDataSyncRequest;
 class iDataType;
 class iInteractorEventRecorder;
-class iLegend;
 class iMarker;
 class iMarkerFamily;
-class iMarkerEventObserver;
 class iMeasuringBox;
-class iMeasuringBoxInteractorStyle;
 class iParallelManager;
 class iParticlesViewSubject;
 class iPicker;
@@ -82,7 +79,6 @@ class iWriter;
 class vtkActor2D;
 class vtkImageWriter;
 class vtkInteractorStyle;
-class vtkPointWidget;
 class vtkProp;
 class vtkRenderer;
 class vtkRenderWindow;
@@ -120,10 +116,9 @@ public:
 	IOBJECT_DECLARE_GETSET(BoundingBoxType,mBoxType,int);
 	IOBJECT_DECLARE_GETSET1(ImageMagnification,int);
 	IOBJECT_DECLARE_GETSET(InteractorStyle,mCurrentInteractorStyle,int);
-	IOBJECT_DECLARE_GETSET1(FontScale,int);
-	IOBJECT_DECLARE_GETSET1(FontType,int);
 	IOBJECT_DECLARE_GETSET1(Antialiasing,bool);
-	IOBJECT_DECLARE_GETSET1(MarkerLegendPosition,int);
+	IOBJECT_DECLARE_GETSET1(ArtifactCorrection,bool);
+	IOBJECT_DECLARE_GETSET1(BackgroundImageFixedAspect,bool);
 	IOBJECT_DECLARE_GETSET(BackgroundColor,mBackgroundColor,const iColor&);
 	IOBJECT_DECLARE_GETSET(BackgroundImage,mBackgroundImage,const iString&);
 
@@ -134,6 +129,8 @@ public:
 	IOBJECT_DECLARE_GETSET2(OpenGLCoordinates,bool);
 	IOBJECT_DECLARE_GETSET2(Stereo,bool);
 	IOBJECT_DECLARE_GETSET2(StereoType,int);
+	IOBJECT_DECLARE_GETSET2(FontScale,int);
+	IOBJECT_DECLARE_GETSET2(FontType,int);
 	
 	//
 	//  Image & Animation output keys
@@ -185,8 +182,7 @@ public:
 	IVIEWMODULE_DECLARE_ISSHOW(MeasuringBox);
 	IVIEWMODULE_DECLARE_ISSHOW(ClipPlane);
 	IVIEWMODULE_DECLARE_ISSHOW(GlassClipPlane);
-	IVIEWMODULE_DECLARE_ISSHOW(MarkerLegend);
-	IVIEWMODULE_DECLARE_ISSHOW(StereoAlignmentMarkers);
+	IVIEWMODULE_DECLARE_ISSHOW(StereoAlignmentMarks);
 	IVIEWMODULE_DECLARE_ISSHOW(CameraAlignmentLabel);
 
 	virtual void ShowLabel(bool s, float *v = 0);
@@ -203,6 +199,14 @@ public:
 	static const iObjectKey& KeyPosition();
 	static const iObjectKey& KeySize();
 
+	//
+	//  Marker-controlling keys
+	//
+	static const iObjectKey& KeyMarkerLegend();
+	static const iObjectKey& KeyMarkerLegendPosition();
+	static const iObjectKey& KeyMarkerHandles();
+	static const iObjectKey& KeyMarkerCaptionsTransparent();
+
 	//
 	//  Light keys (for controlling 3 out of 5 lights)
 	//
@@ -224,7 +228,6 @@ public:
 	//
 	//  "Action" keys
 	//
-	static const iObjectKey& KeyPlaceMarker();
 	static const iObjectKey& KeyMoveMarkerCaption();
 	static const iObjectKey& KeyDumpImage();
 	
@@ -271,10 +274,6 @@ public:
 
 	virtual bool BecomeClone(iViewModule *v);
 
-	virtual void PlaceMarker(bool s);
-	virtual void MoveMarkerCaption(bool s);
-	virtual void BuildMarkerLegend(int i = -1);
-
 	inline float GetUpdateTime() const { return mUpdateTime; }
 	virtual float GetMemorySize() const;
 	void UpdatePerformance();
@@ -333,7 +332,7 @@ private:
 	//  Members
 	//
 	int mWinNum;
-	int mFontScale, mFontType, mBoxType, mImageMagnification, mStereoType, mSavedProjection;
+	int mBoxType, mImageMagnification, mStereoType, mSavedProjection;
 
 	iViewModule *mCloneOfModule;
 	iPointerArray<iViewModule> mClones;
@@ -345,10 +344,10 @@ private:
 	bool mIsDebug, mInImageRender;
 
 	bool mIsLabelOn, mIsColorBarsOn, mIsBoundingBoxOn, mIsRulerOn, mIsMeasuringBoxOn, mIsCameraAlignmentLabelOn;
-	bool mIsGlassClipPlaneOn, mIsClipPlaneOn, mAntialiasing;
-	bool mLabelJustificationLeft, mIsMarkerLegendOn, mIsStereoAlignmentMarkersOn;
+	bool mIsGlassClipPlaneOn, mIsClipPlaneOn, mAntialiasing, mArtifactCorrection, mBackgroundImageFixedAspect;
+	bool mLabelJustificationLeft, mIsStereoAlignmentMarksOn;
 
-	int mMarkerLegendPosition, mCurrentInteractorStyle, mRate;
+	int mCurrentInteractorStyle, mRate;
 	float mBoxSize, mUpdateTime;
 
 	iString mLabelName, mLabelUnit;
@@ -385,19 +384,16 @@ private:
 	iAnimator *mAnimator;
 	iDataReader *mDataReader;
 	iInteractorEventRecorder *mEventRecorder;
-	iLegend *mMarkerLegend;
 	iPicker *mPicker;
 	iPointerArray<iDataConsumer> mDataConsumers;
 	iCubeAxesActor *mBox3AxesLabels;
 	vtkTimerLog *mUpdateTimer;
 
 	iWriter *mWriter;
-	vtkPointWidget *mMarkerPlacer;
 	iClipPlane *mClipPlane;
 
 	vtkInteractorStyle *mInteractorStyle[iParameter::__NumInteractorStyles];
 	iCaptionInteractorStyle *mInteractorStyleCaption;
-	iMeasuringBoxInteractorStyle* mInteractorStyleMeasuringBox;
 
 	//
 	//  Event observers
@@ -406,7 +402,6 @@ private:
 	iAbortRenderEventObserver *mObsAbortRender;
 	iSlaveAbortRenderEventObserver *mObsSlaveAbortRender;
 	iRecordEventObserver *mObsRecord;
-	iMarkerEventObserver *mObsMarker;
 
 	//
 	//  iViewSubject-related members
