@@ -35,7 +35,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iobject.h"
 #include "idataconsumer.h"
-#include "ireplicated.h"
+#include "ireplicatedelement.h"
 
 
 #include "iarray.h"
@@ -50,7 +50,6 @@ class iEventObserver;
 class iMarker;
 class iViewSubjectObserver;
 class iViewSubjectPipeline;
-class iViewSubjectReplicator;
 
 
 //
@@ -74,7 +73,7 @@ class iViewSubjectReplicator;
 	static const iObjectKey& KeyReady()
 
 
-class iViewSubject : public iObject, public iDataConsumer, public iReplicated
+class iViewSubject : public iObject, public iDataConsumer, public iReplicatedElement
 {
 	
 	friend class iControlModule;
@@ -128,8 +127,6 @@ public:
 	void SetPosition(const iPosition &p, bool detach = true);
 	inline const iPosition& GetPosition() const { return mPosition; }
 
-	inline iViewSubjectReplicator* GetReplicator() const { return mReplicator; }
-
 	virtual void AttachToMarker(int m);
 	virtual void UpdateAfterMarkerMove();
 	virtual void UpdateAfterMarkerAdd(iMarker * ){}
@@ -139,6 +136,13 @@ public:
 
 	iDataLimits* GetLimits() const;
 
+	//
+	//  Registry for replicated components
+	//
+	void RegisterReplicatedElement(iReplicatedElement *r, bool isData); 
+	void UnRegisterReplicatedElement(iReplicatedElement *r); 
+	const iReplicatedElement* GetDataReplicated() const { return (mDataReplicated.Size() > 0) ? mDataReplicated[0] : 0; }
+
 	//
 	//  Pipeline operation
 	//
@@ -168,6 +172,7 @@ protected:
     virtual void ViewSubjectSyncWithData(const iDataSyncRequest &r) = 0;
 	virtual iDataHelper* CreateDataHelper(vtkDataSet *ds) const;
 
+	virtual void UpdateReplicasHead();
 	virtual void UpdateReplicasBody();
 	virtual void UpdatePosition(const iPosition &oldPos);
 	
@@ -188,7 +193,6 @@ protected:
 	bool mCreatingMainPipeline;
 
 	iViewSubjectObserver *mObjectObserver;
-	iViewSubjectReplicator *mReplicator;
 	iString mObjectName;
 	int mObjectType, mAttachedMarkerIndex;
 	iPosition mPosition;
@@ -199,6 +203,11 @@ protected:
 
 	iMarker *mAttachedMarker;
 
+	//
+	//  ReplicationElement members
+	//
+	iSearchableArray<iReplicatedElement*> mDataReplicated, mPropReplicated;
+
 	//
 	//  Material properties
 	//
