@@ -125,9 +125,9 @@ int iVolumeDataConverter::ExecuteStep(int, iParallel::ProcessorInfo &p)
 
 	for(l=lBeg; l<lEnd; l++)
 	{
-		if(l%1000==0 && this->IsMaster(p))
+		if(l%1000 == 0)
 		{
-			this->UpdateProgress((float)l/lEnd);
+			if(this->IsMaster(p)) this->UpdateProgress((float)l/lEnd);
 			if(this->GetAbortExecute()) break;
 		}
 
