@@ -47,7 +47,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ireplicatedvolume.h"
 #include "iviewmodule.h"
 #include "iviewsubjectobserver.h"
-#include "iviewsubjectreplicator.h"
 #include "ivolumedataconverter.h"
 
 #include <vtkToolkits.h>
@@ -59,7 +58,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkVolumeRayCastMapper.h>
 #include <vtkVolumeTextureMapper2D.h>
 
-#ifndef IVTK_4
+#ifndef IVTK_44
 #include <vtkFixedPointVolumeRayCastMapper.h> 
 //#include <vtkVolumeShearWarpMapper.h> 
 #include <vtkVolumeTextureMapper3D.h>
@@ -142,7 +141,7 @@ namespace iVolumeViewSubject_Private
 			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
 			mMapper->IntermixIntersectingGeometryOn();
 			mMapper->AutoAdjustSampleDistancesOn();
-#ifdef IVTK_4
+#ifdef IVTK_44
 			mMapper->UseImageClipperOff();
 #endif
 			mMapper->SetInput(input);
@@ -212,7 +211,7 @@ namespace iVolumeViewSubject_Private
 		{
 			mMapper = vtkVolumeTextureMapper2D::New(); IERROR_ASSERT(mMapper);
 			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
-#ifdef IVTK_4
+#ifdef IVTK_44
 			mMapper->UseImageClipperOff();
 #endif
 			mMapper->SetInput(input);
@@ -230,7 +229,7 @@ namespace iVolumeViewSubject_Private
 
 		virtual void SetBlendMode(int m)
 		{
-#ifndef IVTK_4
+#ifndef IVTK_44
 			mMapper->SetBlendMode(m);
 #endif
 		}
@@ -241,7 +240,7 @@ namespace iVolumeViewSubject_Private
 	};
 
 
-#ifndef IVTK_4
+#ifndef IVTK_44
 	class Texture3DHelper : public UniformGridVolumeRenderingHelper
 	{
 
@@ -407,7 +406,7 @@ namespace iVolumeViewSubject_Private
 			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
 			mMapper->IntermixIntersectingGeometryOn();
 			mMapper->SuperSamplingOn();
-#ifdef IVTK_4
+#ifdef IVTK_44
 			mMapper->UseImageClipperOff();
 #endif
 			mMapper->SetInput(input);
@@ -473,7 +472,7 @@ iVolumeViewSubject::iVolumeViewSubject(iViewModule *vm, const iDataType &type, c
 	mImageDownsampleFactor = mDepthDownsampleFactor = 1.0;
 	mBlendMode = 0;
 	
-	mVolume = iReplicatedVolume::New(this->GetReplicator()); IERROR_ASSERT(mVolume);
+	mVolume = iReplicatedVolume::New(this); IERROR_ASSERT(mVolume);
 	mVolume->SetPosition(0.0,0.0,0.0);
 	
 	mVolume->GetProperty()->SetShade(mShading?1:0);
@@ -527,14 +526,14 @@ void iVolumeViewSubject::ConfigureBody()
 	//
 	m = new RayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
 
-#ifndef IVTK_4
+#ifndef IVTK_44
 	m = new FixedPointRayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
 //	m = new ShearWarpRayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
 	mMethod = 2;
 #endif
 
 	m = new Texture2DHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
-#ifndef IVTK_4
+#ifndef IVTK_44
 	m = new Texture3DHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
 #endif
 #ifdef VTK_USE_VOLUMEPRO
