@@ -857,7 +857,7 @@ void iHelpFactory::CreateUserGuide(UGForm form)
 	//
 	//  Create the html file
 	//
-	WriteFile("Work/docs/ug"+kind+".html","<html><title>&copy; 2005-2007 by Nick Gnedin</title><body>"+text+"</body></html>");
+	WriteFile("Work/docs/ug"+kind+".html","<html><title>&copy; 2005-2008 by Nick Gnedin</title><body>"+text+"</body></html>");
 }
 #endif
 
@@ -1038,8 +1038,8 @@ const iString iHelpFactory::FormKeyDescription(const iObjectKey &key, const iStr
 //
 bool iHelpFactory::IsTagPrivate(const char *tag)
 {
-#if IEXTENSION_INCLUDED(IEXTENSION_HART)
-	static const char *hTag = "HART";
+#if IEXTENSION_INCLUDED(IEXTENSION_ART)
+	static const char *hTag = "ART";
 	if(strcmp(tag,hTag) == 0) return true;
 #endif
 	return false;
@@ -1048,13 +1048,13 @@ bool iHelpFactory::IsTagPrivate(const char *tag)
 
 void iHelpFactory::InterpretExtraElements(iString &text, const iString &tag)
 {
-	if(tag.IsEmpty() || tag=="HART")
+	if(tag.IsEmpty() || tag=="ART")
 	{
-#if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		text.Replace("<extra type=HART>","");
+#if IEXTENSION_INCLUDED(IEXTENSION_ART)
+		text.Replace("<extra type=ART>","");
 		text.Replace("</extra>","");
 #else
-		text.RemoveFormatting("<extra type=HART>","</extra>");
+		text.RemoveFormatting("<extra type=ART>","</extra>");
 #endif
 	}
 	if(tag.IsEmpty() || tag=="GADGET")
@@ -1082,9 +1082,9 @@ const iString& iHelpFactory::GetIconTag(const char *extra)
 {
 	static const iString none;
 
-#if IEXTENSION_INCLUDED(IEXTENSION_HART)
-	static const iString hTag("<img src=\"images::hart.png\">");
-	if(extra!=0 && ((extra[0]=='-' && strcmp(extra+2,"HART")==0) || strcmp(extra,"HART")==0)) return hTag;
+#if IEXTENSION_INCLUDED(IEXTENSION_ART)
+	static const iString hTag("<img src=\"images::art.png\">");
+	if(extra!=0 && ((extra[0]=='-' && strcmp(extra+2,"ART")==0) || strcmp(extra,"ART")==0)) return hTag;
 #endif
 #if IEXTENSION_INCLUDED(IEXTENSION_GADGET)
 	static const iString gTag("<img src=\"images::gadget.png\">");
