@@ -44,7 +44,7 @@ namespace iImageFactory_Private
 
 		if(num == 0)
 		{
-			CreateData("Work/docs/images","Code/help/iimagefactorydata2.h","ac");
+			CreateData("Work/docs/images","Code/help/iimagefactorydata2.h","az");
 			exit(0);
 		}
 
