@@ -67,7 +67,8 @@ protected:
 	virtual bool CanRecognize8BitDisplay(bool check = false) const = 0;
 	virtual bool CanDockWindows() const = 0;
 	virtual bool CanChangeFontSize() const = 0;
-	virtual bool IsWindowManagerModern() const = 0;
+	
+	virtual bool CheckCondition(int flag) const = 0;
 
 	iggShell *mOwner;
 };
