@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgwidgethelper.h"
 
 
@@ -107,3 +111,5 @@ void ibgWidgetHelper::OnString1Body(const iString &v)
 	mOwner->OnString1Body(v);
 	mOwner->UpdateDependents();
 }
+
+#endif
