@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgwidgetsubject.h"
 
 
@@ -50,3 +54,5 @@ ibgWidgetSubject::~ibgWidgetSubject()
 	IERROR_ASSERT(mWidgetHelper);
 	delete mWidgetHelper;
 }
+
+#endif
