@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgwindowsubject.h"
 
 
@@ -104,3 +108,4 @@ bool ibgWindowSubject::IsBlocked() const
 	return mIsBlocked || mIsBeingDeleted;
 }
 
+#endif
