@@ -76,6 +76,15 @@ protected:
 				cerr << text.ToCharPointer();
 				break;
 			}
+		case iConsole::_Notification:
+			{
+				char c;
+				cout << text.ToCharPointer() << endl;
+				cout << "Proceed? (y/n)" << endl;
+				c = getchar();
+				if(c != 'y') exit(0);
+				break;
+			}
 		}
 	}
 };
