@@ -86,12 +86,12 @@ public:
 
 	static ibgDialogSubject*						CreateDialogSubject(iggDialog *owner, const ibgWindowSubject *base, unsigned int mode, const iImage *icon, const iString &title);
 
-	static ibgExtensionWindowSubject*				CreateExtensionWindowSubject(iggExtensionWindow *owner, bool single);
+	static ibgExtensionWindowSubject*				CreateExtensionWindowSubject(iggExtensionWindow *owner);
 
 	static ibgFrameSubject*							CreateFrameSubject(iggFrame *owner, int cols);
-	static ibgFrameBookSubject*						CreateFrameBookSubject(iggFrameBook *owner, bool withFeedback);
+	static ibgFrameBookSubject*						CreateFrameBookSubject(iggFrameBook *owner, bool withFeedback, bool tabsOnTop);
 	static ibgFrameFlipSubject*						CreateFrameFlipSubject(iggFrameFlip *owner, bool expanding);
-	static ibgFrameScrollSubject*					CreateFrameScrollSubject(iggFrameScroll *owner, bool withHor);
+	static ibgFrameScrollSubject*					CreateFrameScrollSubject(iggFrameScroll *owner, bool withHor, bool withVer);
 
 	static ibgMainWindowSubject*					CreateMainWindowSubject(iggMainWindow *owner, int cols);
 	static ibgMenuWindowSubject*					CreateMenuWindowSubject(iggMenuWindow *owner, const iImage *icon, const iString &title);
