@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggdialoganimatingprogress.h"
 
 
@@ -248,3 +252,4 @@ bool iggDialogAnimatingProgress::CanBeClosed()
 	return false;  // make it non-closeable
 }
 
+#endif
