@@ -418,7 +418,7 @@ namespace iggDialogDataExplorer_Private
 							ws.RemoveFormatting("<",">");
 						}
 						ws.ReduceWhiteSpace();
-						wn = ws.Section(" ",0,0).ToInt(ok);
+						wn = ws.Section(" ",0,0).ToInt(ok) - 1;
 #ifdef I_CHECK1
 						if(!ok)
 						{
@@ -497,7 +497,7 @@ namespace iggDialogDataExplorer_Private
 			ws += dummy.Part(0,3+mMaxNameLength-mVariables[n].Name.Length());
 			ws += " window#";
 			if(mSubject->SupportsHTML()) ws += "<b>";
-			ws += iString::FromNumber(mVariables[n].View->GetWindowNumber(),"%2d");
+			ws += iString::FromNumber(mVariables[n].View->GetWindowNumber()+1,"%2d");
 			if(mSubject->SupportsHTML()) ws += "</b>";
 			ws += " data: ";
 			if(mSubject->SupportsHTML()) ws += "<b>";
