@@ -45,6 +45,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggframe.h"
 #include "iggmainwindow.h"
+#include "iggwidgetotherbutton.h"
 #include "iggwidgettext.h"
 
 #include "ibgwidgetbuttonsubject.h"
@@ -198,20 +199,43 @@ namespace iggDialogFileSetExplorer_Private
 		ibgWidgetButtonSubject *mButton;
 		iggDialogFileSetExplorer *mDialog;
 	};
+
+
+	class RefreshButton : public iggWidgetSimpleButton
+	{
+
+	public:
+
+		RefreshButton(iggDialogFileSetExplorer *dialog, iggFrame *parent) : iggWidgetSimpleButton("Refresh",parent)
+		{
+			mDialog = dialog;
+		
+			this->SetBaloonHelp("Refresh file list","Refresh the list of files in case they changed on disk.");
+		}
+
+	protected:
+
+		virtual void Execute()
+		{
+			mDialog->UpdateDialog();
+		}
+
+		iggDialogFileSetExplorer *mDialog;
+	};
 };
 
 
 using namespace iggDialogFileSetExplorer_Private;
 
 
-iggDialogFileSetExplorer::iggDialogFileSetExplorer(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("setexp.png"),"File Set Explorer","sr.gg.df",1)
+iggDialogFileSetExplorer::iggDialogFileSetExplorer(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("setexp.png"),"File Set Explorer","sr.gg.df",3)
 {
 	mMustBeClosed = false;
 	mLoadAll = true;
 
 	mView = new View(this,mFrame);
-	mFrame->AddLine(mView);
-	mFrame->AddLine(new LoadAllCheckBox(this,mFrame));
+	mFrame->AddLine(mView,3);
+	mFrame->AddLine(new LoadAllCheckBox(this,mFrame),(iggWidget *)0,new RefreshButton(this,mFrame));
 
 	this->ResizeContents(300,400);
 }
