@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggdialogloadfile.h"
 
 
@@ -159,3 +163,4 @@ void iggDialogLoadFile::Show(bool)
 	//
 }
 
+#endif
