@@ -172,14 +172,14 @@ namespace iggDialogPaletteEditor_Private
 
 		virtual int GetCurrentPaletteIndex() const
 		{
-			return mEditor->GetCurrentPaletteIndex();
+			return mEditor->GetCurrentPaletteIndex() + 1;
 		}
 
 	protected:
 
 		virtual void SetCurrentPaletteIndexBody(int n)
 		{
-			mEditor->SetCurrentPaletteIndex(n);
+			mEditor->SetCurrentPaletteIndex(n-1);
 		}
 
 		iggDialogPaletteEditor *mEditor;
@@ -423,7 +423,7 @@ void iggDialogPaletteEditor::SetChanged(bool s)
 
 void iggDialogPaletteEditor::SetCurrentPaletteIndex(int n)
 {
-	if(n>=0 && n<this->GetShell()->GetControlModule()->GetNumberOfPalettes())
+	if(n>0 && n<=this->GetShell()->GetControlModule()->GetNumberOfPalettes())
 	{
 		if(mApplyButton->IsEnabled()) this->Apply(true);
 		mCurrentPalette->Copy(this->GetShell()->GetControlModule()->GetPalette(n));
