@@ -616,7 +616,7 @@ iggDialogScriptDebugger::iggDialogScriptDebugger(iggMainWindow *parent) : iggMen
 	this->GetSubject()->SetWindowGeometry(wg);
 
 #if defined(I_DEBUG) && defined(_WIN32)
-	this->LoadFromFile("C:\\Users\\Nick\\IFRIT\\Base\\test3.ias");
+//	this->LoadFromFile("C:\\Users\\Nick\\IFRIT\\Base\\test3.ias");
 #endif
 }
 
