@@ -50,10 +50,10 @@ public:
 	iggFramePaletteSelectionBase(bool witheditor, bool withbrightness, iggFrame *parent);
 	virtual ~iggFramePaletteSelectionBase();
 
-	virtual iPalette* GetCurrentPalette() const = 0; // this non-symmetric form is more versatile
+	virtual iPalette* GetCurrentPalette() const;
 
 	void SetCurrentPaletteIndex(int n);
-	inline int GetCurrentPaletteIndex() const { return mCurrentPaletteIndex; }
+	virtual int GetCurrentPaletteIndex() const = 0;
 
 	static void UpdateAll();
 
@@ -62,7 +62,6 @@ protected:
 	virtual void SetCurrentPaletteIndexBody(int n) = 0;
 
 	static iPointerArray<iggFramePaletteSelectionBase>& List();
-	int mCurrentPaletteIndex;
 };
 
 #endif  // IQTFRAMEPALETTESELECTIONBASE_H
