@@ -128,7 +128,6 @@ using namespace iParameter;
 
 IOBJECT_DEFINE_TYPE(iggMainWindow,MainWindow,-mw,iObjectType::_Helper);  // helper type
 
-IOBJECT_DEFINE_KEY(iggMainWindow,AttachWindows,aw,Bool,1);
 IOBJECT_DEFINE_KEY(iggMainWindow,Docked,d,Bool,1);
 IOBJECT_DEFINE_KEY(iggMainWindow,ExtensionGeometry,eg,Int,4);
 IOBJECT_DEFINE_KEY(iggMainWindow,WindowUnderFocusCurrent,fc,Bool,1);
@@ -184,9 +183,8 @@ namespace iggMainWindow_Private
 	const int _MenuStyleRenderResetAll = 223;
 	const int _MenuStyleSlidersEditable = 224;
 	const int _MenuStyleIsIdiosyncratic = 225;
-	const int _MenuStyleAttachWindows = 226;
-	const int _MenuStyleDetailLoadedDataInfo = 227;
-	const int _MenuStyleAutoRender = 228;
+	const int _MenuStyleDetailLoadedDataInfo = 226;
+	const int _MenuStyleAutoRender = 227;
 	const int _MenuStyleTheme = 230;
 	const int _MenuStyleMax = 300;
 
@@ -245,7 +243,9 @@ namespace iggMainWindow_Private
 	const int _MenuOptionPostScriptPaperFormatL2 = 411;
 	const int _MenuOptionPostScriptOrientationPortrait = 421;
 	const int _MenuOptionPostScriptOrientationLandscape = 422;
-	const int _MenuOptionSettingsGlobal = 430;
+	const int _MenuOptionArtifactCorrection = 431;
+	const int _MenuOptionBackgroundImageFixedAspect = 432;
+	const int _MenuOptionSettingsGlobal = 499;
 	const int _MenuOptionMax = 500;
 
 	const int _MenuHelpContents = 501;
@@ -297,6 +297,10 @@ namespace iggMainWindow_Private
 			{ 
 				Entry("U key","dump the current view into an image."),
 				Entry("F key","toggle the Full Screen mode on and off."),
+				Entry("","--------------------"),
+				Entry("","In addition, when the measuring box is activated, the following keys are accepted:"),
+				Entry("+/- keys","scale the measuring box up/down."),
+				Entry("</> keys","adjust box opacity."),
 				Entry("","(use Style->Show interactor help menu to turn this help off)")
 			};
 
@@ -342,18 +346,6 @@ namespace iggMainWindow_Private
 					Entry("W key","show all solid objects as wireframe (faster).")
 			};
 
-			static Entry dataM[] = 
-			{
-				Entry(   "Measuring box mode",""),
-					Entry("","--------------------"),
-					Entry("Left button","rotate the measuring box around its origin."),
-					Entry("Middle button","translate the measuring box in/out of screen."),
-					Entry("Right button","translate the measuring box along scene axes."),
-					Entry("A/Z keys","scale the measuring box down/up."),
-					Entry("S/X keys","adjust box opacity."),
-					Entry("C key","shift the camera focal point to the box center.")
-			};
-
 			static Entry dataC[] = 
 			{ 
 				Entry(   "Camera path mode",""),
@@ -366,7 +358,6 @@ namespace iggMainWindow_Private
 
 			int i, n = 0;
 			Entry *data = 0;
-			bool b;
 			if(this->GetShell()->GetControlModule()->QueryValue(iViewModule::KeyInteractorStyle(),i))
 			{
 				switch(i)
@@ -392,11 +383,6 @@ namespace iggMainWindow_Private
 					}
 				}
 			}
-			if(this->GetShell()->GetControlModule()->QueryValue(iViewModule::KeyMeasuringBox(),b) && b)
-			{
-				data = dataM;
-				n = sizeof(dataM)/sizeof(Entry);
-			}
 			if(this->GetShell()->GetControlModule()->QueryValue(iAnimator::KeyStyle(),i) && i==4)
 			{
 				data = dataC;
@@ -544,6 +530,27 @@ namespace iggMainWindow_Private
 	};
 
 
+	class HideInteractorHelpButton : public iggWidgetSimpleButton
+	{
+
+	public:
+
+		HideInteractorHelpButton(iggFrame *parent) : iggWidgetSimpleButton("Close help",parent)
+		{
+			this->SetBaloonHelp("Close interactor help");
+		}
+
+	protected:
+
+		virtual void Execute()
+		{
+			this->GetMainWindow()->Block(true);
+			this->GetMainWindow()->ShowInteractorHelp(false);
+			this->GetMainWindow()->Block(false);
+		}
+	};
+
+
 	class Book : public iggFrameBook
 	{
 		
@@ -820,7 +827,7 @@ iggMainWindow::iggMainWindow(iShell *shell) : iObject("MainWindow"), iggMenuWind
 {
 	mInitialized = mDocked = mDoNotOfferToReload = mDetailLoadedDataInfo = mAllowPrePopulateToolBar = false;
 	mInteractorHelp = mToolTips = mOptionsAreGlobal = mWindowUnderFocusCurrent = mAutoRender = true;
-	mIdiosyncratic = mAttachWindows = true;
+	mIdiosyncratic = true;
 
 	mProgressBarMode = 0;
 	mCurrentTheme = -1;
@@ -832,6 +839,7 @@ iggMainWindow::iggMainWindow(iShell *shell) : iObject("MainWindow"), iggMenuWind
 
 	mInMove = false;
 	mPrevPos[0] = mPrevPos[1] = -1;
+	mNextPos[0] = mNextPos[1] = -1;
 
 	mMainWindow = this;
 
@@ -912,7 +920,6 @@ void iggMainWindow::StartInitialization()
 	iggShell *s = iRequiredCast<iggShell>(INFO,this->GetShell());
 	
 	if(s->IsDesktopSmall(true)) mLog->Show(false);
-	if(s->IsDesktopSmall(false)) mAttachWindows = false;
 	if(s->CheckCondition(iggParameter::_ConditionSlowRemoteConnection))
 	{
 		ibgRenderWindowSubject::RenderOnFocus = true;
@@ -978,9 +985,10 @@ void iggMainWindow::StartInitialization()
 	//
 	//  Interactor help frame
 	//
-	tmpf = new iggFrame("",mBaseFrame);
-	tmpf->AddLine(new iggWidgetTextArea("%b%+Interactor Help",tmpf));
-	tmpf->AddLine(new InteractorHelpTextView(tmpf));
+	tmpf = new iggFrame("",mBaseFrame,3);
+	tmpf->AddLine(new iggWidgetTextArea("%b%+Interactor Help",tmpf),3);
+	tmpf->AddLine(new InteractorHelpTextView(tmpf),3);
+	tmpf->AddLine((iggWidget *)0,new HideInteractorHelpButton(tmpf),(iggWidget *)0);
 	tmpf->SetRowStretch(0,1);
 	tmpf->SetRowStretch(1,10);
 	mBaseFrame->AddLayer(tmpf);
@@ -1779,7 +1787,6 @@ void iggMainWindow::PackStateBody(iString &s) const
 	this->PackValue(s,KeyWindowUnderFocusCurrent(),mWindowUnderFocusCurrent);
 	this->PackValue(s,KeyAllowPrePopulateToolBar(),mAllowPrePopulateToolBar);
 	this->PackValue(s,KeyIsIdiosyncratic(),mIdiosyncratic);
-	this->PackValue(s,KeyAttachWindows(),mAttachWindows);
 	this->PackValue(s,KeyTabMode(),mBook->GetTabMode());
 	this->PackValue(s,KeyTheme(),(mCurrentTheme>=0 && mCurrentTheme<mThemeList.Size())?mThemeList[mCurrentTheme]:"");
 }
@@ -1835,11 +1842,6 @@ void iggMainWindow::UnPackStateBody(const iString &s)
 		mIdiosyncratic = b;
 		this->ClearCache();
 	}
-	if(this->UnPackValue(s,KeyAttachWindows(),b))
-	{
-		mAttachWindows = b;
-		this->ClearCache();
-	}
 	if(this->UnPackValue(s,KeyTabMode(),i))	this->SetTabMode(i);
 	if(this->UnPackValue(s,KeyTheme(),t))
 	{
@@ -1956,18 +1958,20 @@ void iggMainWindow::DisplayWindowsAsWindows()
 }
 
 
-void iggMainWindow::MoveWindows(bool all)
+void iggMainWindow::MoveWindows(int pos[2], bool all)
 {
+	//
+	//  We must make this function safe against multiple concurrent calls.
+	//  Save the last call.
+	//
+	mNextPos[0] = pos[0];
+	mNextPos[1] = pos[1];
+
 	if(mInMove) return; // ignore rapidly arriving events
 	mInMove = true;
 
-	int pos[2], wg[4];
-
-	this->GetSubject()->GetWindowGeometry(wg);
-	pos[0] = wg[0];
-	pos[1] = wg[1];
-
-	if(all && mInitialized && !mDocked && mAttachWindows) // do not move the first render window
+	int wg[4];
+	if(all && mInitialized && !mDocked) // do not move the first render window
 	{
 		int i, dp[2];
 		dp[0] = pos[0] - mPrevPos[0];
@@ -1991,6 +1995,14 @@ void iggMainWindow::MoveWindows(bool all)
 	mPrevPos[1] = pos[1];
 
 	mInMove = false;
+
+	//
+	//  Check that this function was not called while being executed.
+	//
+	if(mNextPos[0]!=pos[0] || mNextPos[1]!=pos[1])
+	{
+		this->MoveWindows(mNextPos,all);
+	}
 }
 
 
@@ -2106,7 +2118,6 @@ void iggMainWindow::BuildMenus()
 			this->GetSubject()->AddMenuItem(_MenuStyleDockWindow,"&Dock windows",0,"",true,mDocked);
 			this->GetSubject()->AddMenuItem(_MenuStyleSlidersEditable,"&Sliders are editable",0,"",true,iggWidgetSlider::IsEditableByDefault());
 			this->GetSubject()->AddMenuItem(_MenuStyleIsIdiosyncratic,"&Ask for confirmations",0,"",true,mIdiosyncratic);
-			this->GetSubject()->AddMenuItem(_MenuStyleAttachWindows,"&Move windows together",0,"",true,mAttachWindows);
 			this->GetSubject()->AddMenuItem(_MenuStyleDetailLoadedDataInfo,"&Print detail info for loaded data",0,"",true,mDetailLoadedDataInfo);
 			this->GetSubject()->AddMenuItem(_MenuStyleAutoRender,"&Render automatically",0,"",true,mAutoRender);
 		}
@@ -2124,7 +2135,7 @@ void iggMainWindow::BuildMenus()
 	//
 	this->GetSubject()->BeginMenu("&Options",false);
 	{
-		this->GetSubject()->AddMenuItem(_MenuOptionAntialiasing,"Use antialiasing",0,"Shift+Ctrl+Z",true,false,0,false,&iViewModule::KeyAntialiasing());
+		this->GetSubject()->AddMenuItem(_MenuOptionAntialiasing,"Use &antialiasing",0,"Shift+Ctrl+Z",true,false,0,false,&iViewModule::KeyAntialiasing());
 
 		this->GetSubject()->BeginMenu("&Bounding box style",true);
 		{
@@ -2139,7 +2150,6 @@ void iggMainWindow::BuildMenus()
 		{
 			this->GetSubject()->BeginMenu("Font &type",true);
 			{
-				this->GetSubject()->AddMenuItem(_MenuOptionFontTypeVector,"&Vector",0,"",true,false,0,false,&iViewModule::KeyFontType(),_TextTypeVector);
 				this->GetSubject()->AddMenuItem(_MenuOptionFontTypeArial,"&Arial",0,"",true,false,0,false,&iViewModule::KeyFontType(),_TextTypeBitmapArial);
 				this->GetSubject()->AddMenuItem(_MenuOptionFontTypeCourier,"&Courier",0,"",true,false,0,false,&iViewModule::KeyFontType(),_TextTypeBitmapCourier);
 				this->GetSubject()->AddMenuItem(_MenuOptionFontTypeTimes,"&Times",0,"",true,false,0,false,&iViewModule::KeyFontType(),_TextTypeBitmapTimes);
@@ -2223,6 +2233,9 @@ void iggMainWindow::BuildMenus()
 		}
 		this->GetSubject()->EndMenu();
 
+		this->GetSubject()->AddMenuItem(_MenuOptionArtifactCorrection,"&Correct visual artifacts (may be slow)",0,"",true,true,0,false,&iViewModule::KeyArtifactCorrection());
+		this->GetSubject()->AddMenuItem(_MenuOptionBackgroundImageFixedAspect,"&Preserve aspect ratio of background images",0,"",true,true,0,false,&iViewModule::KeyBackgroundImageFixedAspect());
+		
 		this->GetSubject()->AddMenuItem(_MenuOptionSettingsGlobal,"Options apply to all windows",0,"",true,mOptionsAreGlobal);
 	}
 	this->GetSubject()->EndMenu();
@@ -2517,11 +2530,6 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 				mIdiosyncratic = on;
 				break;
 			}
-		case _MenuStyleAttachWindows:
-			{
-				mAttachWindows = on;
-				break;
-			}
 		case _MenuStyleDetailLoadedDataInfo:
 			{
 				mDetailLoadedDataInfo = on;
@@ -2602,11 +2610,6 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 				}
 				break;
 			}
-		case _MenuOptionFontTypeVector:
-			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontType(),_TextTypeVector);
-				break;
-			}
 		case _MenuOptionFontTypeArial:
 			{
 				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontType(),_TextTypeBitmapArial);
@@ -2852,6 +2855,16 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyImageMagnification(),100);
 				break;
 			}
+		case _MenuOptionArtifactCorrection:
+			{
+				this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyArtifactCorrection(),on);
+				break;
+			}
+		case _MenuOptionBackgroundImageFixedAspect:
+			{
+				this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyBackgroundImageFixedAspect(),on);
+				break;
+			}
 		case _MenuOptionSettingsGlobal:
 			{
 				mOptionsAreGlobal = on;
