@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggpagemain.h"
 
 
@@ -67,3 +71,4 @@ void iggPageMain::UpdateChildren()
 	if(this->IsVisible()) this->GetMainWindow()->GetDataTypeFrame()->ShowLayer(mFlipIndex);
 }
 
+#endif
