@@ -84,6 +84,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetselectionboxsubject.h"
 #include "ibgwidgethelper.h"
 
+#include <vtkCamera.h>
+#include <vtkRenderer.h>
+
 #include "iggsubjectfactory.h"
 #include "iggparameter.h"
 using namespace iggParameter;
@@ -859,38 +862,6 @@ namespace iggPageView_Private
 	};
 
 
-	class MarkerMoveButton : public iggWidgetKeyToggleButton
-	{
-
-	public:
-
-		MarkerMoveButton(iggFrameCreateDeleteButton *buddy1, iggWidgetKeyComboBox *buddy2, const iString &text, const iObjectKey &key, iggFrame *parent) : iggWidgetKeyToggleButton(0,text,key,parent,-1,0)
-		{
-			mBuddy1 = buddy1;
-			mBuddy2 = buddy2;
-		}
-
-		void SetBuddy3(MarkerMoveButton *buddy3)
-		{
-			mBuddy3 = buddy3;
-		}
-
-		virtual void QueryValue(bool &val) const
-		{
-			iggWidgetKeyToggleButton::QueryValue(val);
-			mBuddy1->SetActive(!val);
-			mBuddy2->Enable(!val);
-			mBuddy3->Enable(!val);
-		}
-
-	protected:
-
-		iggFrameCreateDeleteButton *mBuddy1;
-		iggWidgetKeyComboBox *mBuddy2;
-		MarkerMoveButton *mBuddy3;
-	};
-
-
 	class MarkerPositionFrame : public iggFramePosition, public iggRenderWindowObserver
 	{
 
@@ -932,6 +903,31 @@ namespace iggPageView_Private
 		}
 	};
 
+	class MarkerMoveCaptionsButton : public iggWidgetKeyExecButton
+	{
+
+	public:
+
+		MarkerMoveCaptionsButton(const iString &text, const iObjectKey &key, iggFrame *parent) : iggWidgetKeyExecButton(text,key,parent,-1,0)
+		{
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			this->iggWidgetKeyExecButton::UpdateWidgetBody();
+
+			bool hasCaptions = false;
+			int i, n = this->GetShell()->GetControlModule()->GetViewModule()->GetMarkerFamily()->GetMaxMemberIndex() + 1;
+			for(i=0; !hasCaptions && i<n; i++)
+			{
+				if(!this->GetShell()->GetControlModule()->GetViewModule()->GetMarkerFamily()->GetMember(i)->GetCaptionText().IsEmpty()) hasCaptions = true;
+			}
+			this->Enable(hasCaptions);
+		}
+	};
+
 
 	class ShowRulerCheckBox : public iggWidgetKeyCheckBox
 	{
@@ -1231,6 +1227,74 @@ namespace iggPageView_Private
 		iggWidgetSimpleSpinBox **mBoxes;
 	};
 
+	class WindowSizeList : public iggWidget
+	{
+
+	public:
+
+		WindowSizeList(iggWidgetSimpleSpinBox **boxes, iggFrame *parent) : iggWidget(parent)
+		{
+			mBoxes = boxes;
+			mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,"");
+
+			this->SetBaloonHelp("Select the size for the visualization window");
+		}
+
+	protected:
+
+		virtual void OnInt1Body(int n)
+		{
+			iString s = mSubject->GetText(n);
+
+			int j, k;
+			bool ok;
+			for(j=0; j<2; j++)
+			{
+				k = s.Section(" x ",j,j).ToInt(ok);
+				if(ok) mBoxes[j]->SetValue(k);
+			}
+		}
+
+		virtual void UpdateWidgetBody()
+		{
+		}
+
+		iggWidgetSimpleSpinBox **mBoxes;
+		ibgWidgetComboBoxSubject *mSubject;
+	};
+
+	class WindowSizeList1 : public WindowSizeList
+	{
+
+	public:
+
+		WindowSizeList1(iggWidgetSimpleSpinBox **boxes, iggFrame *parent) : WindowSizeList(boxes,parent)
+		{
+			mSubject->InsertItem("Rectangle...");
+			mSubject->InsertItem("300 x 200");
+			mSubject->InsertItem("450 x 300");
+			mSubject->InsertItem("700 x 450");
+			mSubject->InsertItem("1000 x 700");
+			mSubject->InsertItem("1500 x 1000");
+		}
+	};
+
+	class WindowSizeList2 : public WindowSizeList
+	{
+
+	public:
+
+		WindowSizeList2(iggWidgetSimpleSpinBox **boxes, iggFrame *parent) : WindowSizeList(boxes,parent)
+		{
+			mSubject->InsertItem("Square...");
+			mSubject->InsertItem("200 x 200");
+			mSubject->InsertItem("300 x 300");
+			mSubject->InsertItem("450 x 450");
+			mSubject->InsertItem("700 x 700");
+			mSubject->InsertItem("1000 x 1000");
+		}
+	};
+
 	class WindowSizeDialog : public iggDialog
 	{
 
@@ -1238,18 +1302,19 @@ namespace iggPageView_Private
 
 		WindowSizeDialog(iggMainWindow *parent) : iggDialog(parent,_DialogModal,0,"Visualization Window Size",0,2,"Set")
 		{
-			mBox[0] = new iggWidgetSimpleSpinBox(120,32768,1,"",mFrame);
-			mBox[1] = new iggWidgetSimpleSpinBox(120,32768,1,"",mFrame);
+			mBoxes[0] = new iggWidgetSimpleSpinBox(120,32768,1,"",mFrame);
+			mBoxes[1] = new iggWidgetSimpleSpinBox(120,32768,1,"",mFrame);
 
 			iggFrame* tmp = new iggFrame(mFrame,2);
-			tmp->AddLine(new WindowSizeButton(mBox,"half",0.5f,tmp),new WindowSizeButton(mBox,"double",2.0f,tmp));
+			tmp->AddLine(new WindowSizeButton(mBoxes,"half",0.5f,tmp),new WindowSizeButton(mBoxes,"double",2.0f,tmp));
 			mFrame->AddLine(tmp,2);
-			mFrame->AddLine(new iggWidgetTextArea("%bWidth:",mFrame),mBox[0]);
-			mFrame->AddLine(new iggWidgetTextArea("%bHeight:",mFrame),mBox[1]);
+			mFrame->AddLine(new WindowSizeList1(mBoxes,mFrame),new WindowSizeList2(mBoxes,mFrame));
+			mFrame->AddLine(new iggWidgetTextArea("%bWidth:",mFrame),mBoxes[0]);
+			mFrame->AddLine(new iggWidgetTextArea("%bHeight:",mFrame),mBoxes[1]);
 			mFrame->AddSpace(10);
 
-			mBox[0]->SetBaloonHelp("Set window width","Set the width of the current visualization window.");
-			mBox[1]->SetBaloonHelp("Set window height","Set the height of the current visualization window.");
+			mBoxes[0]->SetBaloonHelp("Set window width","Set the width of the current visualization window.");
+			mBoxes[1]->SetBaloonHelp("Set window height","Set the height of the current visualization window.");
 		}
 
 		virtual void Show(bool s)
@@ -1257,8 +1322,8 @@ namespace iggPageView_Private
 			if(s)
 			{
                 const int *size = this->GetShell()->GetControlModule()->GetViewModule()->GetRenderWindowSize();
-				mBox[0]->SetValue(size[0]);
-				mBox[1]->SetValue(size[1]);
+				mBoxes[0]->SetValue(size[0]);
+				mBoxes[1]->SetValue(size[1]);
 			}
 			iggDialog::Show(s);
 		}
@@ -1268,14 +1333,14 @@ namespace iggPageView_Private
 		virtual bool CanBeClosed()
 		{
 			const int *s = this->GetShell()->GetControlModule()->GetViewModule()->GetRenderWindowSize();
-			if(s[0]!=mBox[0]->GetValue() || s[1]!=mBox[1]->GetValue())
+			if(s[0]!=mBoxes[0]->GetValue() || s[1]!=mBoxes[1]->GetValue())
 			{
-				this->GetShell()->GetControlModule()->GetViewModule()->SetRenderWindowSize(mBox[0]->GetValue(),mBox[1]->GetValue());
+				this->GetShell()->GetControlModule()->GetViewModule()->SetRenderWindowSize(mBoxes[0]->GetValue(),mBoxes[1]->GetValue());
 			}
 			return true;
 		}
 
-		iggWidgetSimpleSpinBox *mBox[2];
+		iggWidgetSimpleSpinBox *mBoxes[2];
 	};
 
 
@@ -1346,6 +1411,86 @@ namespace iggPageView_Private
 			}
 		}
 	};
+
+
+	class MoveCameraButton : public iggWidgetSimpleButton
+	{
+
+	public:
+
+		MoveCameraButton(int dir, iggFrame *parent) : iggWidgetSimpleButton("",parent,true)
+		{
+			mDir = dir;
+			switch(mDir)
+			{
+			case -1:
+				{
+					mSubject->SetIcon(*iImageFactory::FindIcon("moveleft.png"));
+					break;
+				}
+			case 1:
+				{
+					mSubject->SetIcon(*iImageFactory::FindIcon("moveright.png"));
+					break;
+				}
+			case -2:
+				{
+					mSubject->SetIcon(*iImageFactory::FindIcon("movedown.png"));
+					break;
+				}
+			case 2:
+				{
+					mSubject->SetIcon(*iImageFactory::FindIcon("moveup.png"));
+					break;
+				}
+			default:
+				{
+					IERROR_LOW("Invalid direction.");
+				}
+			}
+			this->SetBaloonHelp("Move the camera focal point","This button moves the camera focal point by 10 degrees in the specified direction.");
+		}
+
+	protected:
+
+		virtual void Execute()
+		{
+			static const double angle = 10.0;
+			vtkCamera *cam = this->GetShell()->GetControlModule()->GetViewModule()->GetRenderer()->GetActiveCamera();
+
+			switch(mDir)
+			{
+			case -1:
+				{
+					cam->Yaw(angle);
+					break;
+				}
+			case 1:
+				{
+					cam->Yaw(-angle);
+					break;
+				}
+			case -2:
+				{
+					cam->Pitch(-angle);
+					break;
+				}
+			case 2:
+				{
+					cam->Pitch(angle);
+					break;
+				}
+			default:
+				{
+					IERROR_LOW("Invalid direction.");
+				}
+			}
+			cam->OrthogonalizeViewUp();
+			this->GetShell()->GetControlModule()->GetViewModule()->Render();
+		}
+
+		int mDir;
+	};
 };
 
 
@@ -1404,6 +1549,8 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 		isb->InsertItem("Keyboard");
 		fb2->AddLine(isb);
 
+		//isb->SetItem("Flight",2,false);
+
 		iggFrame *fb3 = new iggFrame("Background",fb2,1);
 		iggWidgetKeyColorSelection *wid = new iggWidgetKeyColorSelection(iViewModule::KeyBackgroundColor(),fb3,true);
 		if(this->GetMainWindow()->GetDialogImageComposer() != 0) wid->AddDependent(this->GetMainWindow()->GetDialogImageComposer()->GetArea());
@@ -1433,15 +1580,21 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 		//  Camera page
 		//
 		{
-			iggFrame *sbpage0 = new iggFrame(sb,2);
+			iggFrame *sbpage0 = new iggFrame(sb,3);
 			sb->AddPage("Camera",icon,sbpage0);
 
 			iggFrame *vf = new iggFrame("View angle",sbpage0,1);
 			vf->AddSpace(1);
 			vf->AddLine(new iggWidgetKeyFloatSlider(10.0,120.0,110,0,3,"",iCamera::KeyViewAngle(),_RenderModeUseGlobal,vf));
 			vf->AddLine(new iggWidgetKeyCheckBox("Vertical",iCamera::KeyViewAngleVertical(),vf));
-			vf->AddSpace(1);
-			sbpage0->AddLine(vf);
+			vf->AddSpace(10);
+
+			iggFrame *cb = new iggFrame("Camera orientatioin",sbpage0,3);
+			cb->AddLine(static_cast<iggWidget*>(0),new MoveCameraButton(2,cb),static_cast<iggWidget*>(0));
+			cb->AddLine(new MoveCameraButton(-1,cb),static_cast<iggWidget*>(0),new MoveCameraButton(1,cb));
+			cb->AddLine(static_cast<iggWidget*>(0),new MoveCameraButton(-2,cb),static_cast<iggWidget*>(0));
+
+			sbpage0->AddLine(vf,cb);
 			sbpage0->AddSpace(2);
 
 			iggFrame *crf = new iggFrame("Camera clipping range",sbpage0,5);
@@ -1449,11 +1602,11 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			crf->AddLine(cfa,3);
 			crf->AddLine(new ClippingRangeButton(0,cfa,crf),new ClippingRangeButton(1,cfa,crf),new iggWidgetTextArea("Adjust clipping range",crf),new ClippingRangeButton(2,cfa,crf),new ClippingRangeButton(3,cfa,crf));
 			crf->AddLine(new ClippingRangeDisplay(0,crf),2,new iggWidgetTextArea("(in units of focal distance)",crf),1,new ClippingRangeDisplay(1,crf),2);
-			sbpage0->AddLine(crf);
+			sbpage0->AddLine(crf,2);
 			sbpage0->AddSpace(2);
 
 			sbpage0->AddSpace(4);
-			sbpage0->SetColStretch(1,10);
+			sbpage0->SetColStretch(2,10);
 		}
 		//
 		//  Lights page
@@ -1513,7 +1666,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 				sm->InsertItem("Dresden display");
 				vbpage0->AddLine(sm,new iggWidgetTextArea("To toggle in and out\n of stereo mode,\n press 3 within\n the visualization window",vbpage0));
 				vbpage0->AddLine(new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Angle between eyes",iCamera::KeyEyeAngle(),_RenderModeUseGlobal,vbpage0),2);
-				vbpage0->AddLine(new iggWidgetKeyCheckBox("Show alighnment markers in a two-window mode",iViewModule::KeyStereoAlignmentMarkers(),vbpage0),2);
+				vbpage0->AddLine(new iggWidgetKeyCheckBox("Show alighnment marks in a two-window mode",iViewModule::KeyStereoAlignmentMarks(),vbpage0),2);
 
 				vbpage0->AddSpace(10);
 				vbpage0->SetColStretch(1,10);
@@ -1599,7 +1752,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			iggFrame *tmp = new iggFrame(abpage0);
 			iggWidgetKeyRadioBox *ao = new iggWidgetKeyRadioBox(1,"Animation output",0,iViewModule::KeyAnimationOutput(),tmp);
 			ao->InsertItem("Series of images");
-#ifndef IVTK_4
+#ifndef IVTK_44
 
 #ifdef IVTK_SUPPORTS_MPEG
 			ao->InsertItem("MPEG2 movie");
@@ -1811,35 +1964,45 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			mb->AddPage("Main",icon,mbpage0);
 
 			iggFrame *msb = new MarkerFrameBox(mbpage0);
-			CurrentMarkerBox *mcm = new CurrentMarkerBox(msb);
-			msb->AddLine(new iggWidgetTextArea("Current",msb),mcm);
-			iggWidgetKeyComboBox *mcs = new iggWidgetKeyComboBox("",0,iMarker::KeyType(),msb);
+
+			iggFrame *msb1 = new iggFrame(msb);
+			iggFrame *msb2 = new iggFrame(msb);
+			msb->AddLine(msb1,msb2);
+
+			CurrentMarkerBox *mcm = new CurrentMarkerBox(msb2);
+			msb1->AddLine(new iggWidgetTextArea("Current",msb1));
+			msb2->AddLine(mcm);
+			iggWidgetKeyComboBox *mcs = new iggWidgetKeyComboBox("",0,iMarker::KeyType(),msb2);
 			mcs->AddDependent(mcm);
 			mcm->AddDependent(mbpage0);
 			for(i=0; i<__NumPointTypes; i++)
 			{
 				mcs->InsertItem(iPointGlyph::GetName(i));
 			}
-			msb->AddLine(new iggWidgetTextArea("Type",msb),mcs);
-			msb->AddLine(new iggWidgetTextArea("Caption",msb),new iggWidgetKeyTextLineEdit(false,"",iMarker::KeyCaptionText(),_RenderModeUseGlobal,msb));
-			msb->AddLine(new iggWidgetTextArea("Marker size",msb),new iggWidgetKeySizeSlider(1.0e-5,0,"",iMarker::KeySize(true),_RenderModeUseGlobal,msb));
+
+			iggWidget *mct = new iggWidgetKeyTextLineEdit(false,"",iMarker::KeyCaptionText(),_RenderModeUseGlobal,msb2);
+
+			msb1->AddLine(new iggWidgetTextArea("Type",msb1));
+			msb2->AddLine(mcs);
+			msb1->AddLine(new iggWidgetTextArea("Caption",msb1));
+			msb2->AddLine(mct);
+			msb1->AddLine(new iggWidgetTextArea("Marker size",msb1));
+			msb2->AddLine(new iggWidgetKeySizeSlider(1.0e-5,0,"",iMarker::KeySize(true),_RenderModeUseGlobal,msb2));
 
 			iggFrame *mcb = new iggFrame("Controls",mbpage0,1);
 			iggFrameCreateDeleteButton *mcd = new iggFrameCreateDeleteButton(page3,iMarker::Type(),false,"marker",mcb);
 			mcd->AddDependent(mbpage0);
 			mcb->AddLine(mcd);
 
-			MarkerMoveButton *mmm = new MarkerMoveButton(mcd,mcm,"Move marker",iViewModule::KeyPlaceMarker(),mcb);
-			MarkerMoveButton *mmc = new MarkerMoveButton(mcd,mcm,"Move caption",iViewModule::KeyMoveMarkerCaption(),mcb);
-			mmm->SetBuddy3(mmc);
-			mmc->SetBuddy3(mmm);
-
-			mcb->AddLine(mmm);
+			iggWidget *mmc = new MarkerMoveCaptionsButton("Rearrange captions",iViewModule::KeyMoveMarkerCaption(),mcb);
+			iggWidget *mmm = new iggWidgetKeyCheckBox("Show motion handles",iViewModule::KeyMarkerHandles(),mcb);
 			mcb->AddLine(mmc);
+			mcb->AddLine(mmm);
+			mct->AddDependent(mmc);
 
 			mcb->AddSpace(10);
 
-			mbpage0->AddLine(msb,static_cast<iggWidget*>(0),mcb);
+			mbpage0->AddLine(msb,2,mcb,1);
 
 			iggFrame *mfc = new iggFrame(mbpage0,1);
 			iggWidgetKeyColorSelection *mcc = new iggWidgetKeyColorSelection(iMarker::KeyColor(),mfc,false);
@@ -1867,6 +2030,10 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			mbpage1->AddLine(new iggFrameMaterialProperties(false,false,iMarker::Type(),mbpage1));
 			mbpage1->AddLine(new iggWidgetKeyFloatSlider(0.0f,1.0f,10,0,0,"Opacity",iMarker::KeyOpacity(),_RenderModeUseGlobal,mbpage1));
 
+			iggWidget *mct = new iggWidgetKeyCheckBox("Captions are transparent",iViewModule::KeyMarkerCaptionsTransparent(),mbpage1);
+			mct->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionAll);
+			mbpage1->AddLine(mct);
+
 			mbpage1->AddSpace(10);
 			mbpage1->SetColStretch(0,10);
 			mbpage1->SetColStretch(1,3);
