@@ -96,7 +96,7 @@ public:
 	//
 	//  Other pure virtual overwrites which we do not need
 	//
-#ifndef IVTK_4
+#ifndef IVTK_44
 	virtual void Finalize(){}
 #endif
 	virtual int GetEventPending(){ return 0; }
@@ -116,15 +116,19 @@ public:
 	ibgRenderWindowSubject* GetSubject() const { return mSubject; }
 	void OnCloseAttempt();
 
+	virtual bool IsCurrent();
+
 protected:
 
 	iggRenderWindow(iViewModule *vm);
 	virtual ~iggRenderWindow();
 
+	virtual void CreateAWindow(){}
+	virtual void DestroyWindow(){} 
+
 	void AttachToMainWindow(iggMainWindow *mw);
 
 	void Initialize();
-	void SetSizeBody(int w, int h);
 
 	//
 	//  These functions are helpers for image creation
