@@ -37,6 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ipointermacro.h"
+#include "ivtk.h"
 
 class iShell;
 
@@ -87,15 +88,20 @@ public:
 	// as Win32 uses repeating timers, whereas X uses One shot more timer
 	// if flag==VTKXI_TIMER_FIRST Win32 and X should createtimer
 	// otherwise Win32 should exit and X should perform AddTimeOut()
-	virtual int CreateTimer(int); 
-	virtual int DestroyTimer(); 
+#ifdef IVTK_PRE52
+	virtual int CreateTimer(int duration){ return this->InternalCreateTimer(1,1,duration); }
+	virtual int DestroyTimer(){ return this->InternalDestroyTimer(1); }
+#endif
 
 protected:
 
 	iggRenderWindowInteractor(iShell *shell);
 	virtual ~iggRenderWindowInteractor();
 
-	//
+	virtual int InternalCreateTimer(int timerId, int timerType, unsigned long duration);
+	virtual int InternalDestroyTimer(int platformTimerId);
+
+//
 	//  Mouse and keyboard interaction
 	//
 	void OnMouseMove(int x, int y, int b);
@@ -103,6 +109,9 @@ protected:
 	void OnMouseRelease(int x, int y, int b);
 	void OnKeyPress(char k, int b);
 	void OnTimer();
+	void OnEnter();
+	void OnLeave();
+	void OnExpose();
 };
 
 #endif //IGGRENDERWINDOWINTERACTOR_H
