@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggwidgetarea.h"
 
 
@@ -292,4 +296,4 @@ void iggWidgetHistogramArea::AddExtra(iggFrameHistogramAreaExtra *extra)
 	mExtra = extra;
 }
 
-
+#endif
