@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggwidgetkeyhandler.h"
 
 
@@ -262,3 +266,4 @@ void iggWidgetKeyHandlerBase::SetCheckNullIndexKeys(bool s)
 }
 #endif
 
+#endif
