@@ -36,6 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icontrolmodule.h"
 #include "imath.h"
 #include "ishell.h"
+#include "ivtk.h"
 
 #include "iggframe.h"
 #include "iggrenderwindowobserver.h"
@@ -122,8 +123,13 @@ void iggWidgetKeyTrackBall::OnBool1Body(bool final)
 		//
 		//  Use vtkLight angle convention
 		//
-		a[0] = atan2(dir[1],sqrt(dir[0]*dir[0]+dir[2]*dir[2]))/vtkMath::DegreesToRadians(); 
-		a[1] = atan2(dir[0],dir[2])/vtkMath::DegreesToRadians();
+#ifdef IVTK_PRE54
+		a[0] = vtkMath::RadiansToDegrees()*atan2(dir[1],sqrt(dir[0]*dir[0]+dir[2]*dir[2])); 
+		a[1] = vtkMath::RadiansToDegrees()*atan2(dir[0],dir[2]);
+#else
+		a[0] = vtkMath::DegreesFromRadians(atan2(dir[1],sqrt(dir[0]*dir[0]+dir[2]*dir[2]))); 
+		a[1] = vtkMath::DegreesFromRadians(atan2(dir[0],dir[2]));
+#endif
 		this->GetShell()->GetControlModule()->PackCommand(ws,this->GetKey(),a,2);
 	}
 
@@ -143,8 +149,13 @@ void iggWidgetKeyTrackBall::SetAngles(float elevation, float azimuth)
 	//
 	//  Use vtkLight angle convention
 	//
+#ifdef IVTK_PRE54
 	elevation *= vtkMath::DegreesToRadians();
 	azimuth *= vtkMath::DegreesToRadians();
+#else
+	elevation = vtkMath::RadiansFromDegrees(elevation);
+	azimuth = vtkMath::RadiansFromDegrees(azimuth);
+#endif
 	mSubject->SetDirection(cos(elevation)*sin(azimuth),sin(elevation),cos(elevation)*cos(azimuth));
 }
 
