@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggwidgetrendermodebutton.h"
 
 
@@ -190,3 +194,4 @@ void iggWidgetRenderModeButton::ClearLaidOutFlag(const ibgWidgetTrackBallSubject
 	if(t != 0) mWasLaidOut = true;
 }
 
+#endif
