@@ -144,6 +144,8 @@ iqtMainWindowSubject::iqtMainWindowSubject(iggMainWindow *owner) : iqtMenuWindow
 	mMainFrame = 0;
 	mDockingWorkspace = 0;
 
+	mIsMoveAll = false;
+
 	//
 	//  Available themes
 	//
@@ -423,12 +425,26 @@ bool iqtMainWindowSubject::event(QEvent *e)
 }
 
 
+void iqtMainWindowSubject::keyPressEvent(QKeyEvent *e)
+{
+	mIsMoveAll = (e->key() == Qt::Key_Shift);
+	QMainWindow::keyPressEvent(e);
+}
+
+
+void iqtMainWindowSubject::keyReleaseEvent(QKeyEvent *e)
+{
+	mIsMoveAll = false;
+	QMainWindow::keyReleaseEvent(e);
+}
+
+
 void iqtMainWindowSubject::moveEvent(QMoveEvent *e)
 {
-	if(e != 0)
-	{
-		mMainWindow->MoveWindows(QCursor::pos().x()>(this->x()+this->width()/10) && QCursor::pos().x()<(this->x()+this->width()) && QCursor::pos().y()>this->y() && QCursor::pos().y()<(this->y()+this->height()));
-	}
+	int pos[2];
+	pos[0] = this->x();
+	pos[1] = this->y();
+	mMainWindow->MoveWindows(pos,mIsMoveAll);
 	QMainWindow::moveEvent(e);
 }
 
@@ -439,4 +455,15 @@ void iqtMainWindowSubject::closeEvent(QCloseEvent *e)
 	mMainWindow->Exit();
 }
 
+
+void iqtMainWindowSubject::resizeEvent(QResizeEvent *e)
+{
+	static const iString tmp("New size");
+
+#ifdef I_DEBUG
+	mMainWindow->WriteToLog(tmp,iString::FromNumber(e->size().width())+"x"+iString::FromNumber(e->size().height()));
+#endif
+	QMainWindow::resizeEvent(e);
+}
+
 #endif
