@@ -40,6 +40,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "iimagefactory.h"
 #include "iviewmodule.h"
+#include "ivtk.h"
 
 #include "iggmainwindow.h"
 #include "iggrenderwindow.h"
@@ -49,6 +50,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iqtmainwindowsubject.h"
 #include "iqtwindowhelper.h"
 
+#include <vtkRenderWindowInteractor.h>
+
 #ifdef IQT_3
 #include <qapplication.h>
 #include <qimage.h> 
@@ -62,6 +65,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QtGui/QMouseEvent>
 #endif
 
+//
+//  Templates
+//
+#include "iarraytemplate.h"
+
 
 iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget* parent) : 
 #ifdef IQT_3
@@ -89,14 +97,17 @@ iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget*
 	this->setAutoBufferSwap(false);
 
 	if(parent!=0 && parent->layout()!=0) iDynamicCast<QGridLayout,QLayout>(INFO,parent->layout())->addWidget(this,0,0);
-
-	mTimer = new QTimer(this); IERROR_ASSERT(mTimer);
-	if(!connect(mTimer,SIGNAL(timeout()),this,SLOT(OnTimer()))) IERROR_FATAL("Missed connection.");
 }
 
 
 iqtRenderWindowSubject::~iqtRenderWindowSubject() 
 {
+	int i;
+	//
+	//  Do we have undeleted timers?
+	//
+	for(i=0; i<mTimers.Size(); i++) delete mTimers[i];
+
 	if(this->parentWidget() != 0)
 	{
 		this->AttachToParent(0);
@@ -231,23 +242,38 @@ bool iqtRenderWindowSubject::IsReadyForDumpingImage()
 //
 //  RenderWindowInteractor methods
 //
-int iqtRenderWindowSubject::CreateTimer(int) 
+int iqtRenderWindowSubject::InternalCreateTimer(int /*timerId*/, int timerType, unsigned long duration)
 {
+	QTimer *timer = new QTimer(this); IERROR_ASSERT(timer);
+	if(!connect(timer,SIGNAL(timeout()),this,SLOT(OnTimer()))) IERROR_FATAL("Missed connection.");
+
+	mTimers.Add(timer);
 	//
 	// Start a one-shot timer for 10ms. 
 	//
-#ifdef IQT_3
-	mTimer->start(10,true);
+#ifdef IVTK_PRE52
+	bool ss = true;
 #else
-	mTimer->setSingleShot(true);
-	mTimer->start(10);
+	bool ss = (timerType==vtkRenderWindowInteractor::OneShotTimer);
 #endif
-	return 1;
+#ifdef IQT_3
+	timer->start(duration,ss);
+#else
+	timer->setSingleShot(ss);
+	timer->start(duration);
+#endif
+	return mTimers.Size();
 }
 
 
-int iqtRenderWindowSubject::DestroyTimer() 
+int iqtRenderWindowSubject::InternalDestroyTimer(int platformTimerId)
 {
+	if(platformTimerId<1 || platformTimerId>mTimers.Size()) return 0;
+	platformTimerId--;
+
+	mTimers[platformTimerId]->stop();
+	delete mTimers[platformTimerId];
+	mTimers.Remove(platformTimerId);
 	//
 	// QTimer will automatically expire after 10ms. So 
 	// we do not need to do anything here.
@@ -264,7 +290,7 @@ void iqtRenderWindowSubject::initializeGL()
 	//
 	//  I don't think we need this - it crashes X-server over the remote connection
 	//
-	mOwner->OpenGLInit();
+	//mOwner->OpenGLInit();
 }
 
 
@@ -340,6 +366,12 @@ void iqtRenderWindowSubject::OnTimer()
 }
 
 
+bool iqtRenderWindowSubject::IsCurrent()
+{
+	return this->context() == QGLContext::currentContext();
+}
+
+
 bool iqtRenderWindowSubject::event(QEvent *e)
 {
 	//
@@ -400,8 +432,9 @@ void iqtRenderWindowSubject::leaveEvent(QEvent *e)
 
 void iqtRenderWindowSubject::resizeEvent(QResizeEvent *e)
 {
-    QGLWidget::resizeEvent(e);
+	QGLWidget::resizeEvent(e);
 	this->OnWindowResizeBody();
+	//qApp->removePostedEvents(this);
 }
 
 
