@@ -153,9 +153,9 @@ bool iqtShellSubject::CanChangeFontSize() const
 }
 
 
-bool iqtShellSubject::IsWindowManagerModern() const
+bool iqtShellSubject::CheckCondition(int /* flag */) const
 {
-	return true;  // seems not possible to discover from Qt?
+	return false;  // seems not possible to discover from Qt?
 }
 
 #endif
