@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtwidgethelpbrowsersubject.h"
 
 
@@ -159,3 +163,4 @@ QVariant iqtWidgetHelpBrowserSubject::loadResource(int type, const QUrl &name)
 
 #endif
 
+#endif
