@@ -132,6 +132,16 @@ void iqtWidgetSpinBoxSubject::SetRange(int min, int max)
 }
 
 
+void iqtWidgetSpinBoxSubject::SetStep(int step)
+{
+#ifdef IQT_3
+	mBox->setLineStep(step);
+#else
+	mBox->setSingleStep(step);
+#endif
+}
+
+
 void iqtWidgetSpinBoxSubject::SetStretch(int title, int box)
 {
 	QGridLayout *l = iDynamicCast<QGridLayout,QLayout>(INFO,this->layout());
@@ -174,6 +184,7 @@ iqtWidgetComboBoxSubject::iqtWidgetComboBoxSubject(iggWidget *owner, const iStri
 	mTitle->setText(iqtHelper::ConvertWithModifiers(mTitle,title));
 	mTitle->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 	l->addWidget(mTitle,0,0);
+	if(title.IsEmpty()) mTitle->hide();
 
 	mBox = new QComboBox(this);
 	mBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Minimum));
