@@ -44,6 +44,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <qlayout.h>
 #include <qpixmap.h>
 #include <qwidget.h>
+#include <qgl.h>  //  needed for diabling close button under windows
 #else
 #include <QtGui/QApplication>
 #include <QtGui/QIcon>
@@ -51,12 +52,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QtGui/QPixmap>
 #include <QtGui/QResizeEvent>
 #include <QtGui/QWidget>
+#include <QtOpenGL/QGLWidget>  //  needed for diabling close button under windows
 #endif
 
+
 //
 //  Main class
 //
-iqtWindowHelper::iqtWindowHelper(QWidget *widget, const iImage *icon, const iString &title) : ibgWindowHelper(icon,title)
+iqtWindowHelper::iqtWindowHelper(QWidget *widget, const iImage *icon, const iString &title, bool disableClose) : ibgWindowHelper(icon,title)
 {
 	mWidget = widget; IERROR_ASSERT(widget);
 
@@ -77,6 +80,16 @@ iqtWindowHelper::iqtWindowHelper(QWidget *widget, const iImage *icon, const iStr
 		mWidget->setWindowTitle(iqtHelper::Convert(title));
 #endif
 	}
+
+#ifdef _WIN32
+	if(disableClose)
+	{
+		HMENU hmenu = GetSystemMenu(widget->winId(),false);
+//		DeleteMenu(hmenu,SC_CLOSE,MF_BYCOMMAND);  //ok actually remove the close button
+		EnableMenuItem(hmenu,SC_CLOSE,MF_BYCOMMAND|MF_GRAYED);  //ok actually remove the close button
+	}
+#endif
+
 }
 
 
